/**************************************************************************
 |                                                                         
 |                    STATA SETUP FILE FOR ICPSR 02346
 |        WASHINGTON, DC, METROPOLITAN AREA DRUG STUDY (DC*MADS),
 |                1991: HOMELESS AND TRANSIENT POPULATION
 |
 |
 |  Please edit this file as instructed below.
 |  To execute, start Stata, change to the directory containing:
 |       - this do file
 |       - the ASCII data file
 |       - the dictionary file
 |
 |  Then execute the do file (e.g., do 02346-0001-statasetup.do)
 |
 **************************************************************************/

set mem 7m  /* Allocating 7 megabyte(s) of RAM for Stata SE to read the
                 data file into memory. */


set more off  /* This prevents the Stata output viewer from pausing the
                 process */

/****************************************************

Section 1: File Specifications
   This section assigns local macros to the necessary files.
   Please edit:
        "data-filename" ==> The name of data file downloaded from ICPSR
        "dictionary-filename" ==> The name of the dictionary file downloaded.
        "stata-datafile" ==> The name you wish to call your Stata data file.

   Note:  We assume that the raw data, dictionary, and setup (this do file) all
          reside in the same directory (or folder).  If that is not the case
          you will need to include paths as well as filenames in the macros.

********************************************************/

local raw_data "data-filename"
local dict "dictionary-filename"
local outfile "stata-datafile"

/********************************************************

Section 2: Infile Command

This section reads the raw data into Stata format.  If Section 1 was defined
properly, there should be no reason to modify this section.  These macros
should inflate automatically.

**********************************************************/

infile using `dict', using (`raw_data') clear


/*********************************************************

Section 3: Value Label Definitions
This section defines labels for the individual values of each variable.
We suggest that users do not modify this section.

**********************************************************/


label data "Washington, DC, Metropolitan Area Drug Study (DC*MADS), 1991: Homeless and Transient Population, Dataset 0001"

#delimit ;
label define A1        1 "Yes" 2 "No" 3 "Edited yes from Section A"
                       4 "Edited yes from Section I" ;
label define A2        -9 "Legitimate skip" -8 "Missing"
                       -5 "Bad or illegible data" -4 "Don't know" ;
label define A3        -9 "Legitimate skip" -8 "Missing" -4 "Don't know" ;
label define A4D       -9 "Legitimate skip" -8 "Missing"
                       -5 "Bad or illegible data" 0 "None" ;
label define A4W       -9 "Legitimate skip" -8 "Missing"
                       -5 "Bad or illegible data" 0 "None" ;
label define A4M       -9 "Legitimate skip" -8 "Missing"
                       -5 "Bad or illegible data" 0 "None" ;
label define A4Y       -9 "Legitimate skip" -8 "Missing"
                       -5 "Bad or illegible data" 0 "None" ;
label define A4AD      -9 "Legitimate skip" -8 "Missing" -3 "Not applicable"
                       0 "None" ;
label define A4AW      -9 "Legitimate skip" -8 "Missing" -3 "Not applicable"
                       0 "None" ;
label define A4AM      -9 "Legitimate skip" -8 "Missing" -3 "Not applicable"
                       0 "None" ;
label define A4AY      -9 "Legitimate skip" -8 "Missing" -3 "Not applicable"
                       0 "None" ;
label define A5        -9 "Legitimate skip" -8 "Missing" 1 "A house"
                       2 "An apartment" 3 "A room, paid for by R" 4 "A boat"
                       5 "Some other form of regular housing" ;
label define A6A       -9 "Legitimate skip" -8 "Missing" 1 "Yes" 2 "No" ;
label define A9        -9 "Legitimate skip" -8 "Missing" 1 "Yes" 2 "No"
                       3 "Edited yes" 4 "Edited yes, shelter interview" ;
label define A10       -8 "Missing" 1 "Yes" 2 "No" 3 "Edited yes" ;
label define A10A      -9 "Legitimate skip" -8 "Missing" -4 "Don't know"
                       0 "None" ;
label define A11       -8 "Missing" -7 "Refuse" 1 "Yes" 2 "No" ;
label define A11A      -9 "Legitimate skip" -8 "Missing" -4 "Don't know"
                       0 "None" ;
label define B1        -8 "Missing data" 91 "Never tried cigarette" ;
label define B1A       -9 "Legitimate skip" -8 "Missing data"
                       91 "Never smoked daily" ;
label define B1B       -9 "Legitimate skip" -8 "Missing data"
                       -5 "Bad or illegible data"
                       1 "Within the past week (7 days)"
                       2 "Within the past month (30 days)"
                       3 "1 or more months ago, but less than 6 mo"
                       4 "6 or more months ago, but less than 1 ye"
                       5 "1 or more years ago, but less than 3 yea"
                       6 "3 or more years ago" 7 "Edited 30-day use"
                       8 "Edited past 12-month use" ;
label define B1C       -9 "Legitimate skip" -8 "Missing data"
                       -5 "Bad or illegible data"
                       1 "Less than one cigarette day" 2 "1-5 cigarettes day"
                       3 "About 1/2 pack day" 4 "About pack day"
                       5 "About 1-1/2 packs per day"
                       6 "About packs or more day" ;
label define B2        -8 "Missing data" 1 "Yes" 2 "No" 3 "Edited yes"
                       4 "Edited yes from elsewhere in questionnai" ;
label define B2A       -9 "Legitimate skip" -8 "Missing data" -4 "Don't know" ;
label define B2B       -9 "Legitimate skip" -8 "Missing data"
                       1 "Within the past week (7 days)"
                       2 "Within the past month (30 days)"
                       3 "1 or more months ago, but less than 6 mo"
                       4 "6 or more months ago, but less than 1 ye"
                       5 "1 or more years ago, but less than 3 yea"
                       6 "3 or more years ago" 7 "Edited 30-day use"
                       8 "Edited past 12-month use" ;
label define B2C       -9 "Legitimate skip" -8 "Missing data" -4 "Don't know"
                       0 "None" ;
label define B2D       -9 "Legitimate skip" -8 "Missing data"
                       -5 "Bad or illegible data" -4 "Don't know" 0 "None" ;
label define B2E       -9 "Legitimate skip" -8 "Missing data"
                       -5 "Bad or illegible data" -4 "Don't know" 0 "None" ;
label define B3        -8 "Missing" -7 "Refuse" 1 "Yes" 2 "No" 3 "Edited yes"
                       4 "Edited yes from elsewhere in questionnai" ;
label define B3A       -9 "Legitimate skip" -8 "Missing" -4 "Don't know" ;
label define B3B       -9 "Legitimate skip" -8 "Missing"
                       1 "Within the past week (7 days)"
                       2 "Within the past month (30 days)"
                       3 "1 or more months ago, but less than 6 mo"
                       4 "6 or more months ago, but less than 1 ye"
                       5 "1 or more years ago, but less than 3 yea"
                       6 "3 or more years ago" 7 "Edited 30-day use"
                       8 "Edited past 12-month use" ;
label define B3C       -9 "Legitimate skip" -8 "Missing" 0 "None" ;
label define B3D       -9 "Legitimate skip" -8 "Missing"
                       1 "Less than 1/4 ounce" 2 "About 1/4 ounce"
                       3 "About ounce" 5 "About 3-4 ounces"
                       7 "About 5-6 ounces" ;
label define B4        -8 "Missing" -7 "Refuse" 1 "Yes" 2 "No" ;
label define B4A       -9 "Legitimate skip" -8 "Missing" ;
label define B4B       -9 "Legitimate skip" -8 "Missing"
                       1 "Within the past week (7 days)"
                       2 "Within the past month (30 days)"
                       3 "1 or more months ago, but less than 6 mo"
                       4 "6 or more months ago, but less than 1 ye"
                       5 "1 or more years ago, but less than 3 yea"
                       6 "3 or more years ago" 7 "Edited 30-day use"
                       8 "Edited past 12-month use" ;
label define B4C       -9 "Legitimate skip" -8 "Missing" 0 "None" ;
label define B5        -8 "Missing" -7 "Refuse" 1 "Yes" 2 "No" 3 "Edited yes" ;
label define B5A       -9 "Legitimate skip" -8 "Missing" -7 "Refuse" ;
label define B5B       -9 "Legitimate skip" -8 "Missing"
                       1 "Within the past week (7 days)"
                       2 "Within the past month (30 days)"
                       3 "1 or more months ago, but less than 6 mo"
                       4 "6 or more months ago, but less than 1 ye"
                       5 "1 or more years ago, but less than 3 yea"
                       6 "3 or more years ago" 7 "Edited 30-day use"
                       8 "Edited past 12-month use" ;
label define B5C       -9 "Legitimate skip" -8 "Missing" 0 "None" ;
label define B5D       -9 "Legitimate skip" -8 "Missing"
                       -5 "Bad or illegible data" 1 "Less than 1/4 gram"
                       2 "About 1/4 gram" 3 "About 1/2 gram" 4 "About gram"
                       5 "About grams" 6 "More than 2-1/2 grams" ;
label define B6        -8 "Missing" -7 "Refuse" 1 "Yes" 2 "No" 3 "Edited yes"
                       4 "Edited yes from elsewhere in questionnai" ;
label define B6A       -9 "Legitimate skip" -8 "Missing" -7 "Refuse"
                       -4 "Don't know" ;
label define B6B       -9 "Legitimate skip" -8 "Missing"
                       1 "Within the past week (7 days)"
                       2 "Within the past month (30 days)"
                       3 "1 or more months ago, but less than 6 mo"
                       4 "6 or more months ago, but less than 1 ye"
                       5 "1 or more years ago, but less than 3 yea"
                       6 "3 or more years ago" 7 "Edited 30-day use"
                       8 "Edited past 12-month use" ;
label define B6C       -9 "Legitimate skip" -8 "Missing" 0 "None" ;
label define B6D       -9 "Legitimate skip" -8 "Missing"
                       1 "Less than 1/4 gram" 2 "About 1/4 gram"
                       3 "About 1/2 gram" 4 "About 1 gram" 5 "About 2 grams"
                       6 "About 3 grams" 7 "More than 3-1/2 grams" ;
label define B6E1      -9 "Legitimate skip" -8 "Missing" -7 "Refuse" 1 "Yes"
                       2 "No" ;
label define B6E2      -9 "Legitimate skip" -8 "Missing" -7 "Refuse" 1 "Yes"
                       2 "No" ;
label define B6E3      -9 "Legitimate skip" -8 "Missing" -7 "Refuse" 1 "Yes"
                       2 "No" ;
label define B6E4      -9 "Legitimate skip" -8 "Missing" -7 "Refuse" 1 "Yes"
                       2 "No" ;
label define B6E5      -9 "Legitimate skip" -8 "Missing" -7 "Refuse" 1 "Yes"
                       2 "No" ;
label define B7        -8 "Missing" 1 "Yes" 2 "No" 3 "Edited yes"
                       4 "Edited yes from elsewhere in questionnai" ;
label define B7A       -9 "Legitimate skip" -8 "Missing" -7 "Refuse"
                       -5 "Bad or illegible data" ;
label define B7B       -9 "Legitimate skip" -8 "Missing" -7 "Refuse"
                       1 "Within the past week (7 days)"
                       2 "Within the past month (30 days)"
                       3 "1 or more months ago, but less than 6 mo"
                       4 "6 or more months ago, but less than 1 ye"
                       5 "1 or more years ago, but less than 3 yea"
                       6 "3 or more years ago" 7 "Edited 30-day use"
                       8 "Edited past 12-month use" ;
label define B7C       -9 "Legitimate skip" -8 "Missing" 0 "None" ;
label define B8        -8 "Missing" -7 "Refuse" 1 "Yes" 2 "No" 3 "Edited yes"
                       4 "Edited yes from elsewhere in questionnai" ;
label define B8A       -9 "Legitimate skip" -8 "Missing" ;
label define B8B       -9 "Legitimate skip" -8 "Missing" -7 "Refuse"
                       1 "Within the past week (7 days)"
                       2 "Within the past month (30 days)"
                       3 "1 or more months ago, but less than 6 mo"
                       4 "6 or more months ago, but less than 1 ye"
                       5 "1 or more years ago, but less than 3 yea"
                       6 "3 or more years ago" 7 "Edited 30-day use"
                       8 "Edited past 12-month use" ;
label define B8C       -9 "Legitimate skip" -8 "Missing" 0 "None" ;
label define B8D1      -9 "Legitimate skip" -8 "Missing" -7 "Refuse" 1 "Yes"
                       2 "No" ;
label define B8D2      -9 "Legitimate skip" -8 "Missing" -7 "Refuse" 1 "Yes"
                       2 "No" ;
label define B8D3      -9 "Legitimate skip" -8 "Missing" -7 "Refuse" 1 "Yes"
                       2 "No" ;
label define B8D4      -9 "Legitimate skip" -8 "Missing" -7 "Refuse" 1 "Yes"
                       2 "No" ;
label define B8D5      -9 "Legitimate skip" -8 "Missing" -7 "Refuse" 1 "Yes"
                       2 "No" ;
label define B9        -8 "Missing" -7 "Refuse" 1 "Yes" 2 "No" 3 "Edited yes"
                       4 "Edited yes from elsewhere in questionnai" ;
label define B9A       -9 "Legitimate skip" -8 "Missing" -4 "Don't know" ;
label define B9B       -9 "Legitimate skip" -8 "Missing" -7 "Refuse"
                       -4 "Don't know" 2 "Within the past month (30 days)"
                       3 "1 or more months ago, but less than 6 mo"
                       4 "6 or more months ago, but less than 1 ye"
                       5 "1 or more years ago, but less than 3 yea"
                       6 "3 or more years ago" 7 "Edited 30-day use"
                       8 "Edited past 12-month use" ;
label define B9C       -9 "Legitimate skip" -8 "Missing" -4 "Don't know"
                       0 "None" ;
label define B10       -8 "Missing" -7 "Refuse" 1 "Yes" 2 "No" 3 "Edited yes"
                       4 "Edited yes from elsewhere in questionnai" ;
label define B10A      -9 "Legitimate skip" -8 "Missing" -4 "Don't know" ;
label define B10B      -9 "Legitimate skip" -8 "Missing" -7 "Refuse"
                       -4 "Don't know" 1 "Within the past week (7 days)"
                       2 "Within the past month (30 days)"
                       3 "1 or more months ago, but less than 6 mo"
                       4 "6 or more months ago, but less than 1 ye"
                       5 "1 or more years ago, but less than 3 yea"
                       6 "3 or more years ago" 7 "Edited 30-day use"
                       8 "Edited past 12-month use" ;
label define B10C      -9 "Legitimate skip" -8 "Missing" 0 "None" ;
label define B11       -8 "Missing" 1 "Yes" 2 "No" 3 "Edited yes"
                       4 "Edited yes from elsewhere in questionnai" ;
label define B11A      -9 "Legitimate skip" -8 "Missing" ;
label define B11B      -9 "Legitimate skip" -8 "Missing" -4 "Don't know"
                       1 "Within the past week (7 days)"
                       2 "Within the past month (30 days)"
                       3 "1 or more months ago, but less than 6 mo"
                       4 "6 or more months ago, but less than 1 ye"
                       5 "1 or more years ago, but less than 3 yea"
                       6 "3 or more years ago" 7 "Edited 30-day use"
                       8 "Edited past 12-month use" ;
label define B11C      -9 "Legitimate skip" -8 "Missing" 0 "None" ;
label define B12_1     -8 "Missing" 0 "No other drugs #1" 141 "Dilantin"
                       209 "Xanax" 251 "sic" 305 "Biphetamine"
                       322 "Methamphetamine" 327 "Black beauties"
                       329 "Robin's eggs" 336 "Diet pills" 363 "Bam(s)"
                       406 "Percodan" 417 "Morphine" 418 "Methadone"
                       422 "Motrin" 435 "Tylenol" 506 "Amyl nitrite"
                       601 "LSD" 602 "Peyote" 604 "Psilcybin" 605 "PCP"
                       606 "Ecstasy, MDMA" 612 "Happy stick, shermstick"
                       614 "MDA" 623 "Mickey Mousers" 637 "Purple haze"
                       638 "Lovelies" 702 "Heroin" 703 "Opium" 814 "Caffeine"
                       822 "Rabbit tobacco" 834 "Loveboat" ;
label define B12_2     -8 "Missing" 0 "No other drugs #2" 115 "Phenobarbital"
                       116 "Methaqualone" 201 "Valium" 327 "Black beauties"
                       415 "Codeine" 417 "Morphine" 457 "Ts and blues"
                       515 "Vicks" 606 "Ecstasy, MDMA"
                       701 "Other opiates, not specified" 804 "Hashish"
                       833 "Bone" ;
label define B12_3     -8 "Missing" 0 "No other drugs #3"
                       324 "Other stimulant, not specified" 636 "STP" ;
label define C1_1      -9 "Legitimate skip" -8 "Missing" ;
label define C1_2      -9 "Legitimate skip" -8 "Missing" ;
label define C1_3      -9 "Legitimate skip" -8 "Missing"
                       0 "Not this drug, but some other drug in li" 1 "Yes" ;
label define C1_4      -9 "Legitimate skip" -8 "Missing"
                       0 "Not this drug, but some other drug in li" 1 "Yes" ;
label define C1_5      -9 "Legitimate skip" -8 "Missing"
                       0 "Not this drug, but some other drug in li" 1 "Yes" ;
label define C1_6      -9 "Legitimate skip" -8 "Missing"
                       0 "Not this drug, but some other drug in li" 1 "Yes" ;
label define C1_7      -9 "Legitimate skip" -8 "Missing"
                       0 "Not this drug, but some other drug in li" 1 "Yes" ;
label define C1_8      -9 "Legitimate skip" -8 "Missing"
                       0 "Not this drug, but some other drug in li" 1 "Yes" ;
label define C1_9      -9 "Legitimate skip" -8 "Missing"
                       0 "Not this drug, but some other drug in li" ;
label define C1_10     -9 "Legitimate skip" -8 "Missing"
                       0 "Not this drug, but some other drug in li" 1 "Yes" ;
label define C1_11     -9 "Legitimate skip" -8 "Missing"
                       0 "Not this drug, but some other drug in li" 1 "Yes" ;
label define C1_12     -9 "Legitimate skip" -8 "Missing"
                       0 "Not this drug, but some other drug in li" 1 "Yes" ;
label define C1_13     -9 "Legitimate skip" -8 "Missing"
                       0 "Not this drug, but some other drug in li" 1 "Yes" ;
label define C1_14     -9 "Legitimate skip" -8 "Missing"
                       0 "Not this drug, but some other drug in li" 1 "Yes" ;
label define C1_91     -9 "Legitimate skip" -8 "Missing"
                       1 "Yes, did not use drugs with alcohol"
                       3 "Did use drugs with alcohol" ;
label define C1_92     -9 "Legitimate skip" -8 "Missing"
                       1 "Yes, did not use drugs" ;
label define C2        -9 "Legitimate skip" -8 "Missing" -7 "Refuse" 1 "Yes"
                       2 "No" 3 "Edited yes" ;
label define C2A1      -9 "Legitimate skip" -8 "Missing" -7 "Refuse"
                       0 "Not this drug, but some other drug in li" 1 "Yes" ;
label define C2A2      -9 "Legitimate skip" -8 "Missing" -7 "Refuse"
                       0 "Not this drug, but some other drug in li" 1 "Yes" ;
label define C2A3      -9 "Legitimate skip" -8 "Missing" -7 "Refuse"
                       0 "Not this drug, but some other drug in li" 1 "Yes" ;
label define C2A4      -9 "Legitimate skip" -8 "Missing" -7 "Refuse"
                       0 "Not this drug, but some other drug in li" ;
label define C2A5      -9 "Legitimate skip" -8 "Missing" -7 "Refuse"
                       0 "Not this drug, but some other drug in li" 1 "Yes" ;
label define C2A6      -9 "Legitimate skip" -8 "Missing" -7 "Refuse"
                       0 "Not this drug, but some other drug in li" 1 "Yes" ;
label define C2A7      -9 "Legitimate skip" -8 "Missing" -7 "Refuse"
                       0 "Not this drug, but some other drug in li" 1 "Yes" ;
label define C2A8      -9 "Legitimate skip" -8 "Missing" -7 "Refuse"
                       0 "Not this drug, but some other drug in li" 1 "Yes" ;
label define C2A9      -9 "Legitimate skip" -8 "Missing" -7 "Refuse"
                       0 "Not this drug, but some other drug in li" 1 "Yes" ;
label define C2A10     -9 "Legitimate skip" -8 "Missing" -7 "Refuse"
                       0 "Not this drug, but some other drug in li" 1 "Yes" ;
label define C2A11     -9 "Legitimate skip" -8 "Missing" -7 "Refuse"
                       0 "Not this drug, but some other drug in li" 1 "Yes" ;
label define C2A12     -9 "Legitimate skip" -8 "Missing" -7 "Refuse"
                       0 "Not this drug, but some other drug in li" 1 "Yes" ;
label define C2A13     -9 "Legitimate skip" -8 "Missing" -7 "Refuse"
                       0 "Not this drug, but some other drug in li" 1 "Yes" ;
label define C2A14     -9 "Legitimate skip" -8 "Missing" -7 "Refuse"
                       -4 "Don't know"
                       0 "Not this drug, but some other drug in li" 1 "Yes" ;
label define C2B       -9 "Legitimate skip" -8 "Missing" -7 "Refuse"
                       1 "Within the past week (7 days)"
                       2 "Within the past month (30 days)"
                       3 "1 or more months ago, but less than 6 mo"
                       4 "6 or more months ago, but less than 1 ye"
                       5 "1 or more years ago, but less than 3 yea"
                       6 "3 or more years ago" 7 "Edited 30-day use"
                       8 "Edited past 12-month use" ;
label define C2C       -9 "Legitimate skip" -8 "Missing" -7 "Refuse" 1 "Yes"
                       2 "No" ;
label define C2D       -9 "Legitimate skip" -8 "Missing" -7 "Refuse"
                       1 "Never" 2 "Rarely or almost never" 3 "Occasionally"
                       4 "About half the time" 6 "Almost always" 7 "Always" ;
label define C2E       -9 "Legitimate skip" -8 "Missing" -7 "Refuse" 1 "Yes"
                       2 "No" ;
label define C2F       -9 "Legitimate skip" -8 "Missing" -7 "Refuse"
                       1 "Never" 2 "Rarely or almost never" 3 "Occasionally"
                       4 "About half the time" 5 "Most of the time"
                       6 "Almost always" ;
label define C2G       -9 "Legitimate skip" -8 "Missing" -7 "Refuse"
                       1 "Never" 2 "Rarely or almost never" 3 "Occasionally"
                       4 "About half the time" 5 "Most of the time"
                       6 "Almost always" ;
label define C2H       -9 "Legitimate skip" -8 "Missing" -7 "Refuse"
                       1 "Never" 2 "Rarely or almost never" 3 "Occasionally"
                       4 "About half the time" 5 "Most of the time"
                       6 "Almost always" 7 "Always" ;
label define C2I       -9 "Legitimate skip" -8 "Missing" 0 "None" ;
label define C3_1      -9 "Legitimate skip" -8 "Missing" -7 "Refuse"
                       0 "Not this answer, but some other answer i" 1 "Yes" ;
label define C3_2      -9 "Legitimate skip" -8 "Missing" -7 "Refuse"
                       0 "Not this answer, but some other answer i" 1 "Yes" ;
label define C3_3      -9 "Legitimate skip" -8 "Missing" -7 "Refuse"
                       0 "Not this answer, but some other answer i" 1 "Yes" ;
label define C3_4      -9 "Legitimate skip" -8 "Missing" -7 "Refuse"
                       0 "Not this answer, but some other answer i" 1 "Yes" ;
label define C3_5      -9 "Legitimate skip" -8 "Missing" -7 "Refuse"
                       0 "Not this answer, but some other answer i" 1 "Yes" ;
label define C3_6      -9 "Legitimate skip" -8 "Missing" -7 "Refuse"
                       0 "Not this answer, but some other answer i" 1 "Yes" ;
label define C3A1      -9 "Legitimate skip" -8 "Missing" -7 "Refuse"
                       0 "Not this answer, but some other answer i" 1 "Yes" ;
label define C3A2      -9 "Legitimate skip" -8 "Missing" -7 "Refuse"
                       0 "Not this answer, but some other answer i" 1 "Yes" ;
label define C3A3      -9 "Legitimate skip" -8 "Missing" -7 "Refuse"
                       0 "Not this answer, but some other answer i" 1 "Yes" ;
label define C3A4      -9 "Legitimate skip" -8 "Missing" -7 "Refuse"
                       0 "Not this answer, but some other answer i" 1 "Yes" ;
label define C3A5      -9 "Legitimate skip" -8 "Missing" -7 "Refuse"
                       0 "Not this answer, but some other answer i" 1 "Yes" ;
label define C3A6      -9 "Legitimate skip" -8 "Missing" -7 "Refuse"
                       0 "Not this answer, but some other answer i" 1 "Yes" ;
label define C4A       -8 "Missing" -7 "Refuse" -4 "Don't know" 1 "No risk"
                       2 "Slight risk" 3 "Moderate risk" 4 "Great risk" ;
label define C4B       -8 "Missing" -7 "Refuse" -4 "Don't know" 1 "No risk"
                       2 "Slight risk" 3 "Moderate risk" 4 "Great risk" ;
label define C4C       -8 "Missing" -7 "Refuse" -4 "Don't know" 1 "No risk"
                       2 "Slight risk" 3 "Moderate risk" 4 "Great risk" ;
label define C4D       -8 "Missing" -7 "Refuse" -4 "Don't know" 1 "No risk"
                       2 "Slight risk" 3 "Moderate risk" 4 "Great risk" ;
label define C4E       -8 "Missing" -7 "Refuse" -4 "Don't know" 1 "No risk"
                       2 "Slight risk" 3 "Moderate risk" 4 "Great risk" ;
label define C4F       -8 "Missing" -7 "Refuse" -4 "Don't know" 1 "No risk"
                       2 "Slight risk" 3 "Moderate risk" 4 "Great risk" ;
label define C4G       -8 "Missing" -7 "Refuse" -4 "Don't know" 1 "No risk"
                       2 "Slight risk" 3 "Moderate risk" 4 "Great risk" ;
label define C4H       -8 "Missing" -7 "Refuse" -4 "Don't know" 1 "No risk"
                       2 "Slight risk" 3 "Moderate risk" 4 "Great risk" ;
label define C4I       -8 "Missing" -7 "Refuse" -4 "Don't know" 1 "No risk"
                       2 "Slight risk" 3 "Moderate risk" 4 "Great risk" ;
label define C4J       -8 "Missing" -7 "Refuse" -4 "Don't know" 1 "No risk"
                       2 "Slight risk" 3 "Moderate risk" 4 "Great risk" ;
label define C4K       -8 "Missing" -7 "Refuse" -4 "Don't know" 1 "No risk"
                       2 "Slight risk" 3 "Moderate risk" 4 "Great risk" ;
label define C4L       -8 "Missing" -7 "Refuse" -4 "Don't know" 1 "No risk"
                       2 "Slight risk" 3 "Moderate risk" 4 "Great risk" ;
label define C5_1      -9 "Legitimate skip" -8 "Missing" -7 "Refuse"
                       0 "Not this drug, but some other drug in li" 1 "Yes" ;
label define C5_2      -9 "Legitimate skip" -8 "Missing" -7 "Refuse"
                       0 "Not this drug, but some other drug in li" 1 "Yes" ;
label define C5_3      -9 "Legitimate skip" -8 "Missing" -7 "Refuse"
                       0 "Not this drug, but some other drug in li" 1 "Yes" ;
label define C5_4      -9 "Legitimate skip" -8 "Missing" -7 "Refuse"
                       0 "Not this drug, but some other drug in li" ;
label define C5_5      -9 "Legitimate skip" -8 "Missing" -7 "Refuse"
                       0 "Not this drug, but some other drug in li" 1 "Yes" ;
label define C5_6      -9 "Legitimate skip" -8 "Missing" -7 "Refuse"
                       0 "Not this drug, but some other drug in li" 1 "Yes" ;
label define C5_7      -9 "Legitimate skip" -8 "Missing" -7 "Refuse"
                       0 "Not this drug, but some other drug in li" 1 "Yes" ;
label define C5_8      -9 "Legitimate skip" -8 "Missing" -7 "Refuse"
                       0 "Not this drug, but some other drug in li" 1 "Yes" ;
label define C5_9      -9 "Legitimate skip" -8 "Missing" -7 "Refuse"
                       0 "Not this drug, but some other drug in li" ;
label define C5_10     -9 "Legitimate skip" -8 "Missing" -7 "Refuse"
                       0 "Not this drug, but some other drug in li" 1 "Yes" ;
label define C5_11     -9 "Legitimate skip" -8 "Missing" -7 "Refuse"
                       0 "Not this drug, but some other drug in li" 1 "Yes" ;
label define C5_12     -9 "Legitimate skip" -8 "Missing" -7 "Refuse"
                       0 "Not this drug, but some other drug in li" 1 "Yes" ;
label define C5_13     -9 "Legitimate skip" -8 "Missing" -7 "Refuse"
                       0 "Not this drug, but some other drug in li" 1 "Yes" ;
label define C5_14     -9 "Legitimate skip" -8 "Missing" -7 "Refuse"
                       0 "Not this drug, but some other drug in li" ;
label define C5_91     -9 "Legitimate skip" -8 "Missing" -7 "Refuse"
                       0 "Needed larger amounts"
                       1 "Did not need larger amounts" ;
label define C5_94     -9 "Legitimate skip" -8 "Missing" -7 "Refuse"
                       0 "Needed larger amounts in last 12 months"
                       1 "Did not use drugs in last 12 months" ;
label define C6_1      -9 "Legitimate skip" -8 "Missing" -7 "Refuse"
                       0 "Not this drug, but some other drug in li" 1 "Yes" ;
label define C6_2      -9 "Legitimate skip" -8 "Missing" -7 "Refuse"
                       0 "Not this drug, but some other drug in li" 1 "Yes" ;
label define C6_3      -9 "Legitimate skip" -8 "Missing" -7 "Refuse"
                       0 "Not this drug, but some other drug in li" 1 "Yes" ;
label define C6_4      -9 "Legitimate skip" -8 "Missing" -7 "Refuse"
                       0 "Not this drug, but some other drug in li" ;
label define C6_5      -9 "Legitimate skip" -8 "Missing" -7 "Refuse"
                       0 "Not this drug, but some other drug in" 1 "Yes" ;
label define C6_6      -9 "Legitimate skip" -8 "Missing" -7 "Refuse"
                       0 "Not this drug, but some other drug in li" 1 "Yes" ;
label define C6_7      -9 "Legitimate skip" -8 "Missing" -7 "Refuse"
                       0 "Not this drug, but some other drug in li" 1 "Yes" ;
label define C6_8      -9 "Legitimate skip" -8 "Missing" -7 "Refuse"
                       0 "Not this drug, but some other drug in li" 1 "Yes" ;
label define C6_9      -9 "Legitimate skip" -8 "Missing" -7 "Refuse"
                       0 "Not this drug, but some other drug in li" 1 "Yes" ;
label define C6_10     -9 "Legitimate skip" -8 "Missing" -7 "Refuse"
                       0 "Not this drug, but some other drug in li" 1 "Yes" ;
label define C6_11     -9 "Legitimate skip" -8 "Missing" -7 "Refuse"
                       0 "Not this drug, but some other drug in li" 1 "Yes" ;
label define C6_12     -9 "Legitimate skip" -8 "Missing" -7 "Refuse"
                       0 "Not this drug, but some other drug in li" 1 "Yes" ;
label define C6_13     -9 "Legitimate skip" -8 "Missing" -7 "Refuse"
                       0 "Not this drug, but some other drug in li" 1 "Yes" ;
label define C6_14     -9 "Legitimate skip" -8 "Missing" -7 "Refuse"
                       0 "Not this drug, but some other drug in li" 1 "Yes" ;
label define C6_91     -9 "Legitimate skip" -8 "Missing" -7 "Refuse"
                       0 "Had withdrawal symptoms"
                       1 "Did not have withdrawal symptoms" ;
label define C7_1      -9 "Legitimate skip" -8 "Missing" -7 "Refuse"
                       0 "Not this drug, but some other drug in li" 1 "Yes" ;
label define C7_2      -9 "Legitimate skip" -8 "Missing" -7 "Refuse"
                       0 "Not this drug, but some other drug in li" 1 "Yes" ;
label define C7_3      -9 "Legitimate skip" -8 "Missing" -7 "Refuse"
                       0 "Not this drug, but some other drug in li" 1 "Yes" ;
label define C7_4      -9 "Legitimate skip" -8 "Missing" -7 "Refuse"
                       0 "Not this drug, but some other drug in li" 1 "Yes" ;
label define C7_5      -9 "Legitimate skip" -8 "Missing" -7 "Refuse"
                       0 "Not this drug, but some other drug in li" 1 "Yes" ;
label define C7_6      -9 "Legitimate skip" -8 "Missing" -7 "Refuse"
                       0 "Not this drug, but some other drug in li" 1 "Yes" ;
label define C7_7      -9 "Legitimate skip" -8 "Missing" -7 "Refuse"
                       0 "Not this drug, but some other drug in li" 1 "Yes" ;
label define C7_8      -9 "Legitimate skip" -8 "Missing" -7 "Refuse"
                       0 "Not this drug, but some other drug in li" 1 "Yes" ;
label define C7_9      -9 "Legitimate skip" -8 "Missing" -7 "Refuse"
                       0 "Not this drug, but some other drug in li" ;
label define C7_10     -9 "Legitimate skip" -8 "Missing" -7 "Refuse"
                       0 "Not this drug, but some other drug in li" 1 "Yes" ;
label define C7_11     -9 "Legitimate skip" -8 "Missing" -7 "Refuse"
                       0 "Not this drug, but some other drug in li" 1 "Yes" ;
label define C7_12     -9 "Legitimate skip" -8 "Missing" -7 "Refuse"
                       0 "Not this drug, but some other drug in li" 1 "Yes" ;
label define C7_13     -9 "Legitimate skip" -8 "Missing" -7 "Refuse"
                       0 "Not this drug, but some other drug in li" 1 "Yes" ;
label define C7_14     -9 "Legitimate skip" -8 "Missing" -7 "Refuse"
                       0 "Not this drug, but some other drug in li" 1 "Yes" ;
label define C7_91     -9 "Legitimate skip" -8 "Missing" -7 "Refuse"
                       0 "Tried to cut down" 1 "Did not try to cut down" ;
label define C8_93     -9 "Legitimate skip" -8 "Missing"
                       0 "No, R had alcohol" 1 "Yes, R was abstinent" ;
label define C8A       -9 "Legitimate skip" -8 "Missing" 1 "Yes" 2 "No" ;
label define C8B       -9 "Legitimate skip" -8 "Missing" 1 "Yes" 2 "No" ;
label define C8C       -9 "Legitimate skip" -8 "Missing" 1 "Yes" 2 "No" ;
label define C8D       -9 "Legitimate skip" -8 "Missing" 1 "Yes" 2 "No" ;
label define C8E       -9 "Legitimate skip" -8 "Missing" 1 "Yes" 2 "No" ;
label define C8F       -9 "Legitimate skip" -8 "Missing" 1 "Yes" 2 "No" ;
label define C8G       -9 "Legitimate skip" -8 "Missing" 1 "Yes" 2 "No" ;
label define C8H       -9 "Legitimate skip" -8 "Missing" 1 "Yes" 2 "No" ;
label define C8I       -9 "Legitimate skip" -8 "Missing" 1 "Yes" 2 "No" ;
label define C9_93     -9 "Legitimate skip" -8 "Missing" 0 "No, R took drugs"
                       1 "Yes, R was abstinent" ;
label define C9A       -9 "Legitimate skip" -8 "Missing" 1 "Yes" 2 "No" ;
label define C9B       -9 "Legitimate skip" -8 "Missing" 1 "Yes" 2 "No" ;
label define C9C       -9 "Legitimate skip" -8 "Missing" 1 "Yes" 2 "No" ;
label define C9D       -9 "Legitimate skip" -8 "Missing" 1 "Yes" 2 "No" ;
label define C9E       -9 "Legitimate skip" -8 "Missing" 1 "Yes" 2 "No" ;
label define C9F       -9 "Legitimate skip" -8 "Missing" 1 "Yes" 2 "No" ;
label define D1        -8 "Missing" 0 "None" ;
label define D1A       -9 "Legitimate skip" -8 "Missing" 1 "Alcohol problems"
                       2 "Drug problems" 3 "Both" ;
label define D1B1      -9 "Legitimate skip" -8 "Missing"
                       0 "Not this drug, but some other drug in li" 1 "Yes" ;
label define D1B2      -9 "Legitimate skip" -8 "Missing"
                       0 "Not this drug, but some other drug in li" 1 "Yes" ;
label define D1B3      -9 "Legitimate skip" -8 "Missing"
                       0 "Not this drug, but some other drug in li" 1 "Yes" ;
label define D1B4      -9 "Legitimate skip" -8 "Missing"
                       0 "Not this drug, but some other drug in li" 1 "Yes" ;
label define D1B5      -9 "Legitimate skip" -8 "Missing"
                       0 "Not this drug, but some other drug in li" 1 "Yes" ;
label define D1B6      -9 "Legitimate skip" -8 "Missing"
                       0 "Not this drug, but some other drug in li" 1 "Yes" ;
label define D1B7      -9 "Legitimate skip" -8 "Missing"
                       0 "Not this drug, but some other drug in li" 1 "Yes" ;
label define D1B8      -9 "Legitimate skip" -8 "Missing"
                       0 "Not this drug, but some other drug in li" 1 "Yes" ;
label define D1B9      -9 "Legitimate skip" -8 "Missing"
                       0 "Not this drug, but some other drug in li" 1 "Yes" ;
label define D1B10     -9 "Legitimate skip" -8 "Missing"
                       0 "Not this drug, but some other drug in li" 1 "Yes" ;
label define D1B11     -9 "Legitimate skip" -8 "Missing"
                       0 "Not this drug, but some other drug in li" 1 "Yes" ;
label define D1B12     -9 "Legitimate skip" -8 "Missing"
                       0 "Not this drug, but some other drug in li" 1 "Yes" ;
label define D1B13     -9 "Legitimate strip" -8 "Missing"
                       0 "Not this drug, but some other drug in li" 1 "Yes" ;
label define D1B14     -9 "Legitimate skip" -8 "Missing"
                       0 "Not this drug, but some other drug in li" 1 "Yes" ;
label define D1C1      -9 "Legitimate skip" -8 "Missing"
                       0 "Not this answer, but some other answer i" 1 "Yes" ;
label define D1C2      -9 "Legitimate skip" -8 "Missing"
                       0 "Not this answer, but some other answer i" 1 "Yes" ;
label define D1C3      -9 "Legitimate skip" -8 "Missing"
                       0 "Not this answer, but some other answer i" 1 "Yes" ;
label define D1C4      -9 "Legitimate skip" -8 "Missing"
                       0 "Not this answer, but some other answer i" 1 "Yes" ;
label define D1C5      -9 "Legitimate skip" -8 "Missing"
                       0 "Not this answer, but some other answer i" 1 "Yes" ;
label define D1C6      -9 "Legitimate skip" -8 "Missing"
                       0 "Not this answer, but some other answer i" 1 "Yes" ;
label define D1C7      -9 "Legitimate skip" -8 "Missing"
                       0 "Not this answer, but some other answer i" 1 "Yes" ;
label define D1C8      -9 "Legitimate skip" -8 "Missing"
                       0 "Not this answer, but some other answer i" 1 "Yes" ;
label define D1C9      -9 "Legitimate skip" -8 "Missing"
                       0 "Not this answer, but some other answer i" 1 "Yes" ;
label define D1C10     -9 "Legitimate skip" -8 "Missing"
                       0 "Not this answer, but some other answer i" 1 "Yes" ;
label define D1C11     -9 "Legitimate skip" -8 "Missing"
                       0 "Not this answer, but some other answer i" 1 "Yes" ;
label define D1C12     -9 "Legitimate skip" -8 "Missing"
                       0 "Not this answer, but some other answer i" 1 "Yes" ;
label define D1C13     -9 "Legitimate skip" -8 "Missing"
                       0 "Not this answer, but some other answer i" 1 "Yes" ;
label define D1C14     -9 "Legitimate skip" -8 "Missing"
                       0 "Not this answer, but some other answer i" 1 "Yes" ;
label define D1C15     -9 "Legitimate skip" -8 "Missing"
                       0 "Not this answer, but some other answer i" 1 "Yes" ;
label define D1C16     -9 "Legitimate skip" -8 "Missing"
                       0 "Not this answer, but some other answer i" 1 "Yes" ;
label define D1C17     -9 "Legitimate skip" -8 "Missing"
                       0 "Not this answer, but some other answer i" 1 "Yes" ;
label define D1C18     -9 "Legitimate skip" -8 "Missing"
                       0 "Not this answer, but some other answer i" 1 "Yes" ;
label define D1C19     -9 "Legitimate skip" -8 "Missing"
                       0 "Not this answer, but some other answer i" 1 "Yes" ;
label define D1D       -9 "Legitimate skip" -8 "Missing"
                       1 "Within the past week (7 days)"
                       2 "Within the past month (30 days)"
                       3 "1 or more months ago, but less than 6 mo"
                       4 "6 or more months ago, but less than 1 ye"
                       5 "1 or more years ago, but less than 3 yea"
                       6 "3 or more years ago" ;
label define D1E       -9 "Legitimate skip" -8 "Missing"
                       -5 "Bad or illegible data" -4 "Don't know" ;
label define D1F       -9 "Legitimate skip" -8 "Missing" -4 "Don't know"
                       1 "Still in treatment"
                       2 "Transferred to another program"
                       3 "Successful termination" 4 "Problem with program"
                       5 "Money" 6 "Family needed me" 7 "Relapse"
                       8 "Unspecified" 9 "Felt he didn't need it"
                       10 "Over illness" 11 "Became ill"
                       12 "Sentencing in trial" 13 "Probation violation"
                       14 "Moved" 15 "Discharged" 16 "Drank/drunk"
                       17 "Didn't want to be there"
                       18 "Put you out because urine was clear"
                       19 "Was jailed" 20 "Left the program"
                       21 "No longer court ordered" ;
label define E1A       -8 "Missing" 1 "Yes" 2 "No" ;
label define E1B       -8 "Missing" -7 "Refuse" 1 "Yes" 2 "No" ;
label define E1C       -8 "Missing" 1 "Yes" 2 "No" ;
label define E1D       -8 "Missing" 1 "Yes" 2 "No" ;
label define E1E       -8 "Missing" -7 "Refuse" 1 "Yes" 2 "No" ;
label define E2        -8 "Missing" 1 "Yes" 2 "No" ;
label define E3        -8 "Missing" 0 "None" ;
label define E4A       -8 "Missing" -7 "Refuse" 1 "Yes" 2 "No" 3 "Edited yes" ;
label define E4B       -9 "Legitimate skip" -8 "Missing" 1 "Yes" 2 "No" ;
label define E5A       -8 "Missing" 1 "Yes" 2 "No" 3 "Edited yes" ;
label define E5B       -9 "Legitimate skip" -8 "Missing" 1 "Yes" 2 "No" ;
label define E6A       -8 "Missing" 1 "Yes" 2 "No" 3 "Edited yes" ;
label define E6B       -9 "Legitimate skip" -8 "Missing" 1 "Yes" 2 "No" ;
label define E7A       -8 "Missing" 1 "Yes" 2 "No" 3 "Edited yes" ;
label define E7B       -9 "Legitimate skip" -8 "Missing" 1 "Yes" 2 "No" ;
label define F1A       -8 "Missing" -4 "Don't know" 1 "Yes" 2 "No" ;
label define F1B       -8 "Missing" 1 "Yes" 2 "No" ;
label define F1C       -8 "Missing" 1 "Yes" 2 "No" ;
label define F1D       -8 "Missing" 1 "Yes" 2 "No" ;
label define F2A       -8 "Missing" 1 "Yes" 2 "No" ;
label define F2B       -8 "Missing" 1 "Yes" 2 "No" ;
label define F2C       -8 "Missing" 1 "Yes" 2 "No" ;
label define F2D       -8 "Missing" 1 "Yes" 2 "No" ;
label define F2E       -8 "Missing" 1 "Yes" 2 "No" ;
label define F2F       -8 "Missing" 1 "Yes" 2 "No" ;
label define F2A_C     0 "None" 1 "Respiratory problems"
                       2 "Breathing problems" 3 "Bronchitis" 4 "Asthma"
                       5 "Hay fever" 6 "Pneumonia" 7 "Emphysema" 8 "Flu"
                       9 "Cold" 10 "Heart problems" 12 "High blood pressure"
                       13 "Anemia" 14 "Heart disease" 15 "Digestive system"
                       17 "Ulcers (stomach)" 19 "Bone problems" 22 "Bursitis"
                       23 "Arthritis" 24 "Nervous problems" 25 "Epilepsy"
                       26 "Migraines" 27 "Convulsions" 29 "Rashes"
                       106 "Skin rash" 108 "Cellulite" 129 "Scoliosis"
                       136 "Inflamation" ;
label define F2B_C     0 "None" 4 "Asthma" 5 "Hay fever" 6 "Pneumonia"
                       8 "Flu" 9 "Cold" 10 "Heart problems"
                       11 "Circulatory systems" 12 "High blood pressure"
                       13 "Anemia" 14 "Heart disease" 15 "Digestive system"
                       16 "Stomach problems" 17 "Ulcers (stomach)"
                       19 "Bone problems" 22 "Bursitis" 23 "Arthritis"
                       24 "Nervous problems" 26 "Migraines" 27 "Convulsions"
                       29 "Rashes" 30 "Sinus problems" 32 "My back"
                       44 "Varicose veins" 51 "Heart murmur" 56 "Seizures"
                       71 "Bowel blockage" 113 "Ligaments"
                       130 "Recovering from crushed ankle" 137 "Osteoporosis" ;
label define F2C_C     0 "None" 3 "Bronchitis" 4 "Asthma" 5 "Hay fever"
                       6 "Pneumonia" 8 "Flu" 9 "Cold"
                       12 "High blood pressure" 13 "Anemia"
                       14 "Heart disease" 15 "Digestive system"
                       16 "Stomach problems" 17 "Ulcers (stomach)"
                       19 "Bone problems" 21 "Paralysis" 23 "Arthritis"
                       25 "Epilepsy" 26 "Migraines" 27 "Convulsions"
                       29 "Rashes" 51 "Heart murmur" 55 "Tendonitis"
                       101 "Leg pain" ;
label define F2D_C     0 "None" 8 "Flu" 9 "Cold" 12 "High blood pressure"
                       13 "Anemia" 14 "Heart disease" 15 "Digestive system"
                       17 "Ulcers (stomach)" 18 "Colitis"
                       20 "Muscle problems" 21 "Paralysis" 22 "Bursitis"
                       23 "Arthritis" 25 "Epilepsy" 26 "Migraines"
                       28 "Skin ulcers" 29 "Rashes" 60 "Allergies"
                       72 "Shakes" 82 "Gout" 103 "Diarrhea"
                       110 "Contact dermatitis" 134 "Muscle cramps"
                       135 "Diarrhea" ;
label define F2E_C     0 "None" 9 "Cold" 17 "Ulcers (stomach)"
                       20 "Muscle problems" 23 "Arthritis"
                       24 "Nervous problems" 25 "Epilepsy" 26 "Migraines"
                       27 "Convulsions" 29 "Rashes" 56 "Seizures"
                       98 "Phlebitis" 144 "Contact dermatitis" ;
label define F2F_C     0 "None" 12 "High blood pressure" 20 "Muscle problems"
                       23 "Arthritis" 25 "Epilepsy" 26 "Migraines"
                       28 "Skin ulcers" 29 "Rashes" 99 "Food poisoning" ;
label define F3        -8 "Missing" 1 "Yes" 2 "No" 3 "Edited yes" ;
label define F3A_A     -9 "Legitimate skip" -8 "Missing"
                       -5 "Bad or illegible data" 1 "Respiratory problems"
                       3 "Bronchitis" 4 "Asthma" 6 "Pneumonia" 8 "Flu"
                       9 "Cold" 12 "High blood pressure"
                       17 "Ulcers (stomach)" 23 "Arthritis"
                       24 "Nervous problems" 25 "Epilepsy" 26 "Migraines"
                       27 "Convulsions" 29 "Rashes" 30 "Sinus problems"
                       31 "Diabetes" 32 "My back" 33 "Blood clot"
                       34 "Yeast infection" 35 "Bleeding from abortion"
                       37 "Tonsilitis" 38 "Pregnant"
                       40 "Psychiatric problems"
                       41 "Soreness of right shoulder" 45 "Hernia"
                       46 "Birth control" 47 "Contractions"
                       48 "Iron supplement" 49 "Sprained ankle"
                       52 "Infected toe" 53 "Hypertension" 54 "HIV"
                       56 "Seizures" 57 "Depression" 58 "Headaches"
                       61 "Leg & foot problems" 73 "Dental problems"
                       74 "'Detox'" 75 "Sickle cell anemia"
                       76 "Remove fluid from legs" 77 "Eczema"
                       78 "Heroin addiction" 80 "Foot pain"
                       81 "Had toes cut off" 82 "Gout" 83 "Acid indigestion"
                       84 "Foot swells" 85 "Aneurysm" 86 "Iron deficiency"
                       87 "Poison ivy" 88 "Tooth infection"
                       91 "Schizophrenia" 93 "Allergy medicine"
                       94 "Back problems" 96 "Abscessed tooth" 97 "Insomnia"
                       100 "Tuberculosis contact" 102 "Infection"
                       104 "High blood sugar" 105 "Nose" 106 "Skin rash"
                       107 "Schizophrenia" 109 "Liver" 111 "Hydrocortisone"
                       112 "Manic depression" 114 "Ribs" 115 "Skin problems"
                       116 "Throat infection" 117 "Sleeping pills"
                       118 "Urinating" 119 "Tylenol 3" 121 "Psychosis"
                       122 "Pain pills for knees" 123 "Iron anemia"
                       124 "Skin cream for rash" 125 "Theodol"
                       127 "Multiple symptoms" 131 "Leg pain" 132 "Bad hip"
                       133 "Stomach cramps" 138 "Gums" 139 "Menopause"
                       140 "Disk in herniated back & neck" 141 "Operation"
                       142 "High red blood platelet count" 143 "Tooth"
                       145 "Ear infection" ;
label define F3A_B     -9 "Legitimate skip" -8 "Missing"
                       -5 "Bad or illegible data" 0 "None"
                       12 "High blood pressure" 13 "Anemia"
                       14 "Heart disease" 15 "Digestive system"
                       17 "Ulcers (stomach)" 23 "Arthritis"
                       24 "Nervous problems" 25 "Epilepsy" 26 "Migraines"
                       29 "Rashes" 30 "Sinus problems" 31 "Diabetes"
                       32 "My back" 36 "Bleeding from abortion" 39 "Anxiety"
                       43 "Eye problems" 50 "Tumors" 57 "Depression"
                       58 "Headaches" 59 "Vitamins" 60 "Allergies"
                       79 "Bladder infection" 90 "STD" 92 "Kidney problems"
                       95 "Fractured chest bone" 120 "Penicillin"
                       126 "Tagumia" 128 "AIDS" ;
label define F3A_C     -9 "Legitimate skip" -8 "Missing" 0 "None"
                       10 "Heart problems" 12 "High blood pressure"
                       23 "Arthritis" 42 "Carpal tunnel syndrome"
                       58 "Headaches" ;
label define F4        -9 "Legitimate skip" -8 "Missing" 1 "Yes" 2 "No"
                       3 "Edited yes" ;
label define F4A       -9 "Legitimate skip" -8 "Missing"
                       3 "1 or more months ago, but less than 6 mo"
                       4 "6 or more months ago, but less than 1 ye"
                       5 "1 or more years ago, but less than 3 yea"
                       6 "3 or more years ago" ;
label define F4B       -9 "Legitimate skip" -8 "Missing" -4 "Don't know"
                       1 "None" 2 "Less than one cigarette a day"
                       3 "1-5 cigarettes a day" 4 "About 1/2 pack a day"
                       5 "About 1 pack a day" 6 "About 1 1/2 packs a day"
                       7 "About 2 packs or more a day" ;
label define F4C       -9 "Legitimate skip" -8 "Missing" 1 "Daily"
                       2 "Almost daily or 3-6 days a week"
                       3 "1-2 days a week" 4 "Several times a month"
                       5 "Monthly or less" 6 "Never" ;
label define F4D       -9 "Legitimate skip" -8 "Missing" 0 "No drugs used"
                       1 "Yes, used some of the drugs below during" ;
label define F4D1      -9 "Legitimate skip" -8 "Missing"
                       0 "Not this drug, but some other drug in li" 1 "Yes" ;
label define F4E1      -9 "Legitimate skip" -8 "Missing"
                       0 "Not this drug, but some other drug in li" 1 "Daily"
                       2 "3-6 days/week" 3 "1-2 days/week"
                       4 "2-4 times/month" 5 "1 time or less/month" ;
label define F4D2      -9 "Legitimate skip" -8 "Missing"
                       0 "Not this drug, but some other drug in li" ;
label define F4E2      -9 "Legitimate skip" -8 "Missing"
                       0 "Not this drug, but some other drug in li" ;
label define F4D3      -9 "Legitimate skip" -8 "Missing"
                       0 "Not this drug, but some other drug in li" 1 "Yes" ;
label define F4E3      -9 "Legitimate skip" -8 "Missing"
                       0 "Not this drug, but some other drug in li" 1 "Daily"
                       2 "3-6 days/week" 3 "1-2 days/week"
                       4 "2-4 times/month" 5 "1 time or less/month" ;
label define F4D4      -9 "Legitimate skip" -8 "Missing"
                       0 "Not this drug, but some other drug in li" 1 "Yes" ;
label define F4E4      -9 "Legitimate skip" -8 "Missing"
                       0 "Not this drug, but some other drug in li"
                       2 "3-6 days/week" 3 "1-2 days/week"
                       4 "2-4 times/month" 5 "1 time or less/month" ;
label define F4D5      -9 "Legitimate skip" -8 "Missing"
                       0 "Not this drug, but some other drug in li" 1 "Yes" ;
label define F4E5      -9 "Legitimate skip" -8 "Missing"
                       0 "Not this drug, but some other drug in li" 1 "Daily"
                       4 "2-4 times/month" ;
label define F4D6      -9 "Legitimate skip" -8 "Missing"
                       0 "Not this drug, but some other drug in li" 1 "Yes" ;
label define F4E6      -9 "Legitimate skip" -8 "Missing"
                       0 "Not this drug, but some other drug in li" 1 "Daily"
                       4 "2-4 times/month" ;
label define F4D7      -9 "Legitimate skip" -8 "Missing"
                       0 "Not this drug, but some other drug in li" ;
label define F4E7      -9 "Legitimate skip" -8 "Missing"
                       0 "Not this drug, but some other drug in li" ;
label define F4D8      -9 "Legitimate skip" -8 "Missing"
                       0 "Not this drug, but some other drug in li" 1 "Yes" ;
label define F4E8      -9 "Legitimate skip" -8 "Missing"
                       0 "Not this drug, but some other drug in li" 1 "Daily" ;
label define F4D9      -9 "Legitimate skip" -8 "Missing"
                       0 "Not this drug, but some other drug in li" 1 "Yes" ;
label define F4E9      -9 "Legitimate skip" -8 "Missing"
                       0 "Not this drug, but some other drug in li"
                       3 "1-2 days/week" 4 "2-4 times/month"
                       5 "1 time or less/month" ;
label define F4D10     -9 "Legitimate skip" -8 "Missing"
                       0 "Not this drug, but some other drug in li" 1 "Yes" ;
label define F4E10     -9 "Legitimate skip" -8 "Missing"
                       0 "Not this drug, but some other drug in li" 1 "Daily"
                       3 "1-2 days/week" 5 "1 time or less/month" ;
label define F4D11     -9 "Legitimate skip" -8 "Missing"
                       0 "Not this drug, but some other drug in li" 1 "Yes" ;
label define F4E11     -9 "Legitimate skip" -8 "Missing"
                       0 "Not this drug, but some other drug in li" 1 "Daily"
                       3 "1-2 days/week" 5 "1 time or less/month" ;
label define F5        -8 "Missing" -4 "Don't know" 1 "Yes" 2 "No"
                       3 "Edited yes" ;
label define F5A1      -9 "Legitimate skip" -8 "Missing" -4 "Don't know"
                       0 "Not this answer, but some other answer i" 1 "Yes" ;
label define F5A2      -9 "Legitimate skip" -8 "Missing" -4 "Don't know"
                       0 "Not this answer, but some other answer i" 1 "Yes" ;
label define F5A3      -9 "Legitimate skip" -8 "Missing" -4 "Don't know"
                       0 "Not this answer, but some other answer i" 1 "Yes" ;
label define F5A4      -9 "Legitimate skip" -8 "Missing" -4 "Don't know"
                       0 "Not this answer, but some other answer i" 1 "Yes" ;
label define F5A5      -9 "Legitimate skip" -8 "Missing" -4 "Don't know"
                       0 "Not this answer, but some other answer i" 1 "Yes" ;
label define F5B       -9 "Legitimate skip" -8 "Missing" 0 "Non public"
                       1 "Public" ;
label define F5C1      -9 "Legitimate skip" -8 "Missing" -4 "Don't know"
                       0 "Not this answer, but some other answer i" 1 "Yes" ;
label define F5C2      -9 "Legitimate skip" -8 "Missing" -4 "Don't know"
                       0 "Not this answer, but some other answer i" 1 "Yes" ;
label define F5C3      -9 "Legitimate skip" -8 "Missing" -4 "Don't know"
                       0 "Not this answer, but some other answer i" 1 "Yes" ;
label define F5C4      -9 "Legitimate skip" -8 "Missing" -4 "Don't know"
                       0 "Not this answer, but some other answer i" 1 "Yes" ;
label define F5C5      -9 "Legitimate skip" -8 "Missing" -4 "Don't know"
                       0 "Not this answer, but some other answer i" 1 "Yes" ;
label define F5C5SP    -9 "Legitimate skip" -8 "Missing" -4 "Don't know"
                       0 "Not this answer, but some other answer i"
                       1 "Other answer specified" ;
label define F5D       -9 "Legitimate skip" -8 "Missing" -4 "Don't know"
                       1 "All or most" 2 "Some" 3 "None" 9 "Does not know" ;
label define F6        -8 "Missing" -4 "Don't know" 0 "None" ;
label define F6A       -9 "Legitimate skip" -8 "Missing" -4 "Don't know"
                       0 "None" ;
label define F6B       -9 "Legitimate skip" -8 "Missing" -4 "Don't know"
                       1 "Within the past week" 2 "Within the past month"
                       3 "1 or more months ago, but less than 6 mo"
                       4 "6 or more months ago, but less than 1 ye"
                       5 "1 or more years ago, but less than 3 yea"
                       6 "3 or more years ago" ;
label define F6C       -9 "Legitimate skip" -8 "Missing" -4 "Don't know"
                       0 "None" ;
label define F7        -8 "Missing" -5 "Bad or illegible data"
                       -4 "Don't know" 0 "None" ;
label define F7A       -9 "Legitimate skip" -8 "Missing" -4 "Don't know"
                       1 "Within the past week" 2 "Within the past month"
                       3 "1 or more months ago, but less than 6 mo"
                       4 "6 or more months ago, but less than 1 ye"
                       5 "1 or more years ago, but less than 3 yea"
                       6 "3 or more years ago" 8 "Edited past 12 months" ;
label define F7B       -9 "Legitimate skip" -8 "Missing"
                       -5 "Bad or illegible data" -4 "Don't know" 0 "None" ;
label define F7C1      -9 "Legitimate skip" -8 "Missing" 0 "None" ;
label define F7C2      -9 "Legitimate skip" -8 "Missing" 0 "None" ;
label define F7C3      -9 "Legitimate skip" -8 "Missing" 0 "None" ;
label define F8        -8 "Missing" -5 "Bad or illegible data"
                       -4 "Don't know" 1 "Within the past week"
                       2 "Within the past month"
                       3 "1 or more months ago, but less than 6 mo"
                       4 "6 or more months ago, but less than 1 ye"
                       5 "1 or more years ago, but less than 3 yea"
                       6 "3 or more years ago" 8 "Edited past 12 months" ;
label define F8A       -9 "Legitimate skip" -8 "Missing" 0 "None" ;
label define G1A       -8 "Missing" 1 "Yes" 2 "No" 3 "Edited yes" ;
label define G1B       -9 "Legitimate skip" -8 "Missing" 1 "Yes" 2 "No" ;
label define G2A       -8 "Missing" 1 "Yes" 2 "No" 3 "Edited yes" ;
label define G2B       -9 "Legitimate skip" -8 "Missing" 1 "Yes" 2 "No" ;
label define G3A       -8 "Missing" 1 "Yes" 2 "No" 3 "Edited yes" ;
label define G3B       -9 "Legitimate skip" -8 "Missing" 1 "Yes" 2 "No" ;
label define G4A       -8 "Missing" -4 "Don't know" 1 "Yes" 2 "No"
                       3 "Edited yes" ;
label define G4B       -9 "Legitimate skip" -8 "Missing" -4 "Don't know"
                       1 "Yes" 2 "No" ;
label define G5A       -8 "Missing" -4 "Don't know" 1 "Yes" 2 "No"
                       3 "Edited yes" ;
label define G5B       -9 "Legitimate skip" -8 "Missing" 1 "Yes" 2 "No" ;
label define G6A       -8 "Missing" 1 "Yes" 2 "No" 3 "Edited yes" ;
label define G6B       -9 "Legitimate skip" -8 "Missing" 1 "Yes" 2 "No" ;
label define G7A       -8 "Missing" 1 "Yes" 2 "No" 3 "Edited yes" ;
label define G7B       -9 "Legitimate skip" -8 "Missing" -4 "Don't know"
                       1 "Yes" 2 "No" ;
label define G8A       -8 "Missing" 1 "Yes" 2 "No" 3 "Edited yes" ;
label define G8B       -9 "Legitimate skip" -8 "Missing" 1 "Yes" 2 "No"
                       3 "Edited yes" ;
label define G9A       -9 "Legitimate skip" -8 "Missing" 1 "Yes" 2 "No" ;
label define G9B       -9 "Legitimate skip" -8 "Missing" 1 "Yes" 2 "No" ;
label define G10       -8 "Missing" -7 "Refuse" 0 "None" ;
label define G10A      -9 "Legitimate skip" -8 "Missing" -7 "Refuse"
                       1 "Within the past week" 2 "Within the past month"
                       3 "1 or more months ago, but less than 6 mo"
                       4 "6 or more months ago, but less than 1 ye"
                       5 "1 or more years ago, but less than 3 yea"
                       6 "3 or more years ago" ;
label define G10B      -9 "Legitimate skip" -8 "Missing"
                       -5 "Bad or illegible data" ;
label define G11       -8 "Missing" -5 "Bad or illegible data"
                       -4 "Don't know" 0 "None" ;
label define G11A      -9 "Legitimate skip" -8 "Missing" -7 "Refuse"
                       1 "Within the past week" 2 "Within the past month"
                       3 "1 or more months ago, but less than 6 mo"
                       4 "6 or more months ago, but less than 1 ye"
                       5 "1 or more years ago, but less than 3 yea"
                       6 "3 or more years ago" ;
label define G11B      -9 "Legitimate skip" -8 "Missing"
                       -5 "Bad or illegible data" -4 "Don't know" 0 "None" ;
label define G12       -8 "Missing" -7 "Refuse" 1 "Yes" 2 "No" 3 "Edited yes" ;
label define G12A1     -9 "Legitimate strip" -8 "Missing" -7 "Refuse"
                       -4 "Don't know"
                       0 "Not this medicine, but some other medici" 1 "Yes" ;
label define G12A2     -9 "Legitimate skip" -8 "Missing" -7 "Refuse"
                       -4 "Don't know"
                       0 "Not this medicine, but some other medici" ;
label define G12A3     -9 "Legitimate skip" -8 "Missing" -7 "Refuse"
                       -4 "Don't know"
                       0 "Not this medicine, but some other medici" ;
label define G12A4     -9 "Legitimate skip" -8 "Missing" -7 "Refuse"
                       -4 "Don't know"
                       0 "Not this medicine, but some other medici" 1 "Yes" ;
label define G12A5     -9 "Legitimate skip" -8 "Missing" -7 "Refuse"
                       -4 "Don't know"
                       0 "Not this medicine, but some other medici" 1 "Yes" ;
label define G12A6     -9 "Legitimate skip" -8 "Missing" -7 "Refuse"
                       -4 "Don't know"
                       0 "Not this medicine, but some other medici" 1 "Yes" ;
label define G12A7     -9 "Legitimate skip" -8 "Missing" -7 "Refuse"
                       -4 "Don't know"
                       0 "Not this medicine, but some other medici" 1 "Yes" ;
label define G12A8     -9 "Legitimate skip" -8 "Missing" -7 "Refuse"
                       -4 "Don't know"
                       0 "Not this medicine, but some other medici" 1 "Yes" ;
label define G12A9     -9 "Legitimate skip" -8 "Missing" -7 "Refuse"
                       -4 "Don't know"
                       0 "Not this medicine, but some other medici" 1 "Yes" ;
label define G12A10    -9 "Legitimate skip" -8 "Missing" -7 "Refuse"
                       -4 "Don't know"
                       0 "Not this medicine, but some other medici" 1 "Yes" ;
label define G12A11    -9 "Legitimate skip" -8 "Missing" -7 "Refuse"
                       -4 "Don't know"
                       0 "Not this medicine, but some other medici" 1 "Yes" ;
label define G12A12    -9 "Legitimate skip" -8 "Missing" -7 "Refuse"
                       -4 "Don't know"
                       0 "Not this medicine, but some other medici" 1 "Yes" ;
label define G12A13    -9 "Legitimate skip" -8 "Missing" -7 "Refuse"
                       -4 "Don't know"
                       0 "Not this medicine, but some other medici" 1 "Yes" ;
label define G12A14    -9 "Legitimate skip" -8 "Missing" -7 "Refuse"
                       -4 "Don't know"
                       0 "Not this medicine, but some other medici" 1 "Yes" ;
label define G12A15    -9 "Legitimate skip" -8 "Missing" -7 "Refuse"
                       -4 "Don't know"
                       0 "Not this medicine, but some other medici" 1 "Yes" ;
label define G12A16    -9 "Legitimate skip" -8 "Missing" -7 "Refuse"
                       -4 "Don't know"
                       0 "Not this medicine, but some other medici" 1 "Yes" ;
label define G12A17    -9 "Legitimate skip" -8 "Missing" -7 "Refuse"
                       -4 "Don't know"
                       0 "Not this medicine, but some other medici" 1 "Yes" ;
label define G12A18    -9 "Legitimate skip" -8 "Missing" -7 "Refuse"
                       -4 "Don't know"
                       0 "Not this medicine, but some other medici" 1 "Yes" ;
label define G12A19    -9 "Legitimate skip" -8 "Missing" -7 "Refuse"
                       -4 "Don't know"
                       0 "Not this medicine, but some other medici" 1 "Yes" ;
label define G12A20    -9 "Legitimate sip" -8 "Missing" -7 "Refuse"
                       -4 "Don't know"
                       0 "Not this medicine, but some other medici" 1 "Yes" ;
label define G12A21    -9 "Legitimate skip" -8 "Missing" -7 "Refuse"
                       -4 "Don't know"
                       0 "Not this medicine, but some other medici" 1 "Yes" ;
label define G12A22    -9 "Legitimate skip" -8 "Missing" -7 "Refuse"
                       -4 "Don't know"
                       0 "Not this medicine, but some other medici" 1 "Yes" ;
label define G12A23    -9 "Legitimate skip" -8 "Missing" -7 "Refuse"
                       -4 "Don't know"
                       0 "Not this medicine, but some other medici" 1 "Yes" ;
label define G12A24    -9 "Legitimate sip" -8 "Missing" -7 "Refuse"
                       -4 "Don't know"
                       0 "Not this medicine, but some other medici" 1 "Yes" ;
label define G12A25    -9 "Legitimate skip" -8 "Missing" -7 "Refuse"
                       -4 "Don't know"
                       0 "Not this medicine, but some other medici" 1 "Yes" ;
label define G12A26    -9 "Legitimate skip" -8 "Missing" -7 "Refuse"
                       -4 "Don't know"
                       0 "Not this medicine, but some other medici" 1 "Yes" ;
label define G12A27    -9 "Legitimate skip" -8 "Missing" -7 "Refuse"
                       -4 "Don't know"
                       0 "Not this medicine, but some other medici" 1 "Yes" ;
label define G12A28    -9 "Legitimate skip" -8 "Missing" -7 "Refuse"
                       -4 "Don't know"
                       0 "Not this medicine, but some other medici" 1 "Yes" ;
label define G12A28S1  -9 "Legitimate skip" -8 "Missing"
                       -5 "Bad or illegible data" -4 "Don't know"
                       113 "Halcion" 115 "Phenobarbital" 131 "Haldol"
                       141 "Dilantin" 201 "Valium" 206 "Tranxene"
                       207 "Ativan" 209 "Xanax" 211 "Buspar" 213 "Equanil"
                       226 "Stelazine" 228 "Amitriptyline" 235 "Imipramine"
                       250 "Aventyl" 252 "Strawberry whip cream"
                       362 "Benadryl" 369 "Artane" 371 "Cogentin"
                       426 "Fiorinal" 435 "Tylenol"
                       801 "Other drugs, not specified"
                       827 "Aluminum chloride" 835 "sic" ;
label define G12A29    -9 "Legitimate skip" -8 "Missing" -7 "Refuse"
                       -4 "Don't know"
                       0 "Not this medicine, but some other medici" 1 "Yes" ;
label define G12A29S   -9 "Legitimate skip" -8 "Missing"
                       -5 "Bad or illegible data" -4 "Don't know"
                       30 "For nerves" 31 "Side effect medication"
                       32 "Depression" 33 "Help me sleep"
                       34 "Helps me from hearing voices"
                       35 "Paranoid schizophrenia" 36 "For PCP use"
                       37 "Calm down" 38 "Back surgery" 39 "Tension"
                       40 "Mood swings" 41 "Anxiety" 42 "Stomach"
                       43 "Seizures" 44 "Bipolar manic depression"
                       45 "To control anger" ;
label define H1MON     -9 "Legitimate skip" -8 "Missing" -4 "Don't know"
                       1 "January" 2 "February" 3 "March" 4 "April" 5 "May"
                       6 "June" 7 "July" 8 "August" 9 "September"
                       10 "October" 11 "November" 12 "December" ;
label define H1YR      -9 "Legitimate skip" -8 "Missing" -4 "Don't know" ;
label define H1N       -9 "Legitimate skip" -8 "Missing"
                       0 "Never worked for pay" ;
label define H1B       -9 "Legitimate skip" -8 "Missing" -4 "Don't know" ;
label define H1C       -9 "Legitimate skip" -8 "Missing" ;
label define H1D       -9 "Legitimate skip" -8 "Missing" 0 "None" ;
label define H2        -8 "Missing" -5 "Bad or illegible data"
                       1 "Working full-time, 35 hours or more week"
                       2 "Working part-time, less than 35 hours we"
                       3 "Have job, not@work-extended illness,mat"
                       4 "Unemployed or laid off and looking for w"
                       5 "Unemployed and not looking for work"
                       6 "Full-time homemaker" 7 "In school only" 8 "Retired"
                       9 "Disabled, not able to work" 10 "In prison"
                       11 "In the military" 12 "Unspecified"
                       25 "Other employed" 26 "Other not employed"
                       27 "Other undetermined" ;
label define H3A       -8 "Missing" 1 "Yes" 2 "No" 3 "Edited yes" ;
label define H3B       -9 "Legitimate skip" -8 "Missing" -7 "Refuse"
                       999 "$999 or more" ;
label define H4A       -8 "Missing" 1 "Yes" 2 "No" ;
label define H4B       -9 "Legitimate skip" -8 "Missing" 999 "$999 or more" ;
label define H5A       -8 "Missing" 1 "Yes" 2 "No" 3 "Edited yes" ;
label define H5B       -9 "Legitimate skip" -8 "Missing" -7 "Refuse"
                       -5 "Bad or illegible data" 999 "$999 or more" ;
label define H6A       -8 "Missing" 1 "Yes" 2 "No" ;
label define H6B       -9 "Legitimate skip" -8 "Missing" -7 "Refuse"
                       -5 "Bad or illegible data" -4 "Don't know"
                       999 "$999 or more" ;
label define H7A       -8 "Missing" 1 "Yes" 2 "No" ;
label define H7B       -9 "Legitimate skip" -8 "Missing" 999 "$999 or more" ;
label define H8A       -8 "Missing" 1 "Yes" 2 "No" ;
label define H8B       -9 "Legitimate skip" -8 "Missing" -4 "Don't know"
                       999 "$999 or more" ;
label define H9A       -8 "Missing" 1 "Yes" 2 "No" ;
label define H9B       -9 "Legitimate skip" -8 "Missing" -4 "Don't know"
                       999 "$999 or more" ;
label define H10A      -8 "Missing" 1 "Yes" 2 "No" ;
label define H10B      -9 "Legitimate skip" -8 "Missing" 999 "$999 or more" ;
label define H11A      -8 "Missing" 1 "Yes" 2 "No" 3 "Edited yes" ;
label define H11B      -9 "Legitimate skip" -8 "Missing" -4 "Don't know"
                       999 "$999 or more" ;
label define H12A      -8 "Missing" 1 "Yes" 2 "No" 3 "Edited yes" ;
label define H12B      -9 "Legitimate skip" -8 "Missing" -4 "Don't know"
                       999 "$999 or more" ;
label define H13A      -8 "Missing" 1 "Yes" 2 "No" ;
label define H13B      -9 "Legitimate skip" -8 "Missing" -4 "Don't know"
                       999 "$999 or more" ;
label define H14A      -8 "Missing" 1 "Yes" 2 "No" ;
label define H14B      -9 "Legitimate skip" -8 "Missing" 999 "$999 or more" ;
label define H14A_A    -9 "Legitimate skip" -8 "Missing"
                       41 "Other entitlement/benefit" 42 "Windfall"
                       43 "Charity" 44 "Self-initiated" ;
label define H14A_B    -9 "Legitimate skip" -8 "Missing"
                       41 "Other entitlement/benefit" 43 "Charity" ;
label define H14A_C    -9 "Legitimate skip" -8 "Missing" ;
label define H15A      -8 "Missing" -7 "Refuse" -4 "Don't know"
                       999 "$999 or more" ;
label define H15B      -8 "Missing" -4 "Don't know" 999 "$999 or more" ;
label define H15C      -8 "Missing" -4 "Don't know" 999 "$999 or more" ;
label define H15D      -8 "Missing" 999 "$999 or more" ;
label define H15E      -8 "Missing" -7 "Refuse" -4 "Don't know"
                       999 "$999 or more" ;
label define H16A      -8 "Missing" 1 "Yes" 2 "No" ;
label define H16B      -8 "Missing" 1 "Yes" 2 "No" ;
label define H16C      -8 "Missing" 1 "Yes" 2 "No" ;
label define H16D      -8 "Missing" 1 "Yes" 2 "No" ;
label define H16E      -8 "Missing" 1 "Yes" 2 "No" ;
label define H16E_A    -9 "Legitimate skip" -8 "Missing" 32 "SSDI"
                       41 "Other entitlements/benefits" ;
label define H16E_AA   -9 "Legitimate skip" -8 "Missing" 1 "Yes" ;
label define H16E_B    -9 "Legitimate skip" -8 "Missing" 41 "VA budget" ;
label define H16E_BB   -9 "Legitimate skip" -8 "Missing" 1 "Yes" ;
label define I1A       -8 "Missing" 1 "Yes" 2 "No" 3 "Edited yes" ;
label define I1BM      -9 "Legitimate skip" -8 "Missing"
                       -5 "Bad or illegible data" -4 "Don't know" 0 "None" ;
label define I1BW      -9 "Legitimate skip" -8 "Missing"
                       -5 "Bad or illegible data" -4 "Don't know" 0 "None" ;
label define I2A       -8 "Missing" 1 "Yes" 2 "No" 3 "Edited yes" ;
label define I2BM      -9 "Legitimate skip" -8 "Missing" 0 "None" ;
label define I2BW      -9 "Legitimate skip" -8 "Missing" 0 "None" ;
label define I3A       -8 "Missing" 1 "Yes" 2 "No" ;
label define I3BM      -9 "Legitimate skip" -8 "Missing" 0 "None" ;
label define I3BW      -9 "Legitimate skip" -8 "Missing" 0 "None" ;
label define I4A       -8 "Missing" 1 "Yes" 2 "No" ;
label define I4BM      -9 "Legitimate skip" -8 "Missing" 0 "None" ;
label define I4BW      -9 "Legitimate skip" -8 "Missing" 0 "None" ;
label define I5A       -8 "Missing" 1 "Yes" 2 "No" ;
label define I5BM      -9 "Legitimate skip" -8 "Missing" 0 "None" ;
label define I5BW      -9 "Legitimate skip" -8 "Missing" 0 "None" ;
label define I6A       -8 "Missing" -7 "Refuse" 1 "Yes" 2 "No" 3 "Edited yes" ;
label define I6BM      -9 "Legitimate skip" -8 "Missing" -7 "Refuse" 0 "None" ;
label define I6BW      -9 "Legitimate skip" -8 "Missing" -7 "Refuse" 0 "None" ;
label define I7A       -8 "Missing" 1 "Yes" 2 "No" 3 "Edited yes" ;
label define I7BM      -9 "Legitimate skip" -8 "Missing" 0 "None" ;
label define I7BW      -9 "Legitimate skip" -8 "Missing" 0 "None" ;
label define I8A       -8 "Missing" 1 "Yes" 2 "No" 3 "Edited yes" ;
label define I8BM      -9 "Legitimate skip" -8 "Missing" 0 "None" ;
label define I8BW      -9 "Legitimate skip" -8 "Missing" 0 "None" ;
label define I9A       -8 "Missing" 1 "Yes" 2 "No" 3 "Edited yes" ;
label define I9BM      -9 "Legitimate skip" -8 "Missing" 0 "None" ;
label define I9BW      -9 "Legitimate skip" -8 "Missing" 0 "None" ;
label define I9AA      -9 "Legitimate skip" -8 "Missing"
                       10 "Hotel/rooming house" 11 "Garage"
                       12 "Too tired to come home" 13 "Transitional shelter"
                       14 "Built own shelter" 15 "Crack house"
                       16 "Foster home" 17 "Transient hotel"
                       18 "Camper/school bus" 19 "Refrigerator box"
                       20 "Woods" 21 "Van" 22 "Farm worker" 23 "Church" ;
label define I9AB      -9 "Legitimate skip" -8 "Missing"
                       0 "Only one other living situation given" ;
label define I9AC      -9 "Legitimate skip" -8 "Missing"
                       0 "Only one other living situation given" ;
label define I10       -8 "Missing" 1 "Own house, apartment, or room"
                       2 "Friend or relatives house, apt, or room"
                       3 "Unsupervised dorm or quarters"
                       4 "Nursing home/any other kind of group hom"
                       5 "Hosp/res facility-med, mental, sub abuse"
                       6 "Correctional institution"
                       7 "Campgrounds/emergency shelter"
                       8 "Vacant bldgs,cars,parks,on street,pub or"
                       9 "Any other situation" ;
label define J1        -8 "Missing" 1 "Male" 2 "Female" ;
label define AGE       -8 "Missing" 17 "12-17" 90 "Over age 55" ;
label define J2A       -9 "Legitimate skip" -8 "Missing"
                       -5 "Bad or illegible data" 1 "Married" 2 "Widowed"
                       3 "Divorced or separated"
                       4 "Not married, but living with partner"
                       5 "Never married" ;
label define J5        -8 "Missing" 0 "No schooling" 8 "Elementary grades"
                       12 "High school grades" 13 "College years"
                       17 "Graduate/professional school" ;
label define J5A       -9 "Legitimate skip" -8 "Missing"
                       1 "High school diploma" 2 "GED certificate"
                       3 "Neither of the above" ;
label define J8_0      -9 "Legitimate skip" -8 "Missing" -4 "Don't know"
                       1 "Yes" ;
label define J8_1      -9 "Legitimate skip" -8 "Missing" -4 "Don't know"
                       0 "Not this answer, but some other answer i" 1 "Yes" ;
label define J8_2      -9 "Legitimate skip" -8 "Missing" -4 "Don't know"
                       0 "Not this answer, but some other answer i" 1 "Yes" ;
label define J8_3      -9 "Legitimate skip" -8 "Missing" -4 "Don't know"
                       0 "Not this answer, but some other answer i" 1 "Yes" ;
label define J8_4      -9 "Legitimate skip" -8 "Missing" -4 "Don't know"
                       0 "Not this answer, but some other answer i" 1 "Yes" ;
label define J8_5      -9 "Legitimate skip" -8 "Missing" -4 "Don't know"
                       0 "Not this answer, but some other answer i" 1 "Yes" ;
label define J8_6      -9 "Legitimate skip" -8 "Missing" -4 "Don't know"
                       0 "Not this answer, but some other answer i" 1 "Yes" ;
label define J8_7      -9 "Legitimate skip" -8 "Missing" -4 "Don't know"
                       0 "Not this answer, but some other answer i" 1 "Yes" ;
label define J8_8      -9 "Legitimate skip" -8 "Missing" -4 "Don't know"
                       0 "Not this answer, but some other answer i" 1 "Yes" ;
label define J8_9      -9 "Legitimate skip" -8 "Missing" -4 "Don't know"
                       0 "Not this answer, but some other answer i" 1 "Yes" ;
label define J9        -8 "Missing" 1 "Yes" 2 "No" 3 "Edited yes" ;
label define J9AY      -9 "Legitimate skip" -8 "Missing" -4 "Don't know"
                       0 "None" ;
label define J9AM      -9 "Legitimate skip" -8 "Missing" -4 "Don't know"
                       0 "None" ;
label define J10       -8 "Missing" -5 "Bad or illegible data"
                       -4 "Don't know" 51 "Over 50 people" ;
label define J11       -8 "Missing" 0 "None" ;
label define J12       -8 "Missing" -4 "Don't know" 0 "None" ;
label define K1        -8 "Missing" 1 "Yes" 2 "No" 3 "Edited yes" ;
label define ADMFLAG   1 "None" 2 "Illicit drug use only"
                       3 "Heavy alcohol use only" 4 "Treatment history only"
                       5 "Drug and heavy alcohol use"
                       6 "Drug use and treatment history"
                       7 "Alcohol use and treatment history"
                       8 "Drug use, heavy alcohol use, & tx histo"
                       9 "Missing" ;
label define ALCFLAG   0 "No" 1 "Yes" 9 "Missing" ;
label define ALCMON    0 "No" 1 "Yes" 9 "Missing" ;
label define ALCUIS    -8.00 "Missing" .00 "None" ;
label define ALCUSE    1 "Current user" 2 "Past user" 3 "Nonuser of alcohol"
                       9 "Missing" ;
label define ALCUSEHV  1 "Current heavy alcohol user" 2 "Other alcohol users"
                       3 "Nonuser of alcohol" 9 "Missing" ;
label define ALCYR     0 "No" 1 "Yes" 9 "Missing" ;
label define ALPRSM_C  1 "None" 2 "1 to 3 problems" 3 "4 to 6 problems"
                       4 "7 to 10 problems" 9 "Missing" ;
label define ALPRSUM   -8 "Missing" 0 "None" ;
label define ANYAGE    -8 "Missing" ;
label define ANYAGE21  1 "Yes" 2 "No" 3 "No information on age at first use" ;
label define ANYFLAG   0 "No" 1 "Yes" 9 "Missing" ;
label define ANYLA     0 "No" 1 "Yes" 9 "Missing" ;
label define ANYLOSS   0 "No" 1 "Yes" 9 "Missing" ;
label define ANYMON    0 "No" 1 "Yes" 9 "Missing" ;
label define ANYSERL   0 "No" 1 "Yes" ;
label define ANYSH     0 "No" 1 "Yes" ;
label define ANYSHSK   0 "No" 1 "Yes" ;
label define ANYSHSKE  0 "No" 1 "Yes" ;
label define ANYSHSKT  1 "Yes" ;
label define ANYTCD    0 "No" 1 "Yes" 9 "Missing" ;
label define ANYUSE    1 "Current drug user" 2 "Past drug user"
                       3 "Nonuser of drugs" 9 "Missing" ;
label define ANYUWA    0 "No" 1 "Yes" 9 "Missing" ;
label define ANYWS     0 "No" 1 "Yes" 9 "Missing" ;
label define ANYYR     0 "No" 1 "Yes" 9 "Missing" ;
label define ARRFLAG   0 "No" 1 "Yes" 9 "Missing" ;
label define B2C_A     -9 "Legitimate skip" -8 "Missing" -4 "Don't know"
                       0 "None" ;
label define B2C_AC    1 "None" 2 "1-4 days" 3 "5-31 days" 9 "Missing" ;
label define B2E_A     -9 "Legitimate skip" -8 "Missing"
                       -5 "Bad or illegible data" -4 "Don't know" 0 "None" ;
label define B2E_AC    1 "None" 2 "1-4 days" 3 "5-31 days" 9 "Missing" ;
label define B3C_A     -9 "Legitimate skip" -8 "Missing" 0 "None" ;
label define B3C_AC    1 "None" 2 "1-4 days" 3 "5-31 days" 9 "Missing" ;
label define B5C_A     -9 "Legitimate skip" -8 "Missing" 0 "None" ;
label define B5C_AC    1 "None" 2 "1-4 days" 3 "5-31 days" 9 "Missing" ;
label define B6C_A     -9 "Legitimate skip" -8 "Missing" 0 "None" ;
label define B6C_AC    1 "None" 2 "1-4 days" 3 "5-31 days" 9 "Missing" ;
label define B8C_A     -9 "Legitimate skip" -8 "Missing" 0 "None" ;
label define B8C_AC    1 "None" 2 "1-4 days" 3 "5-31 days" 9 "Missing" ;
label define BD_AGE_E  -8 "Missing" 17 "Under age 18" 90 "Over age 55" ;
label define C3A1_C    0 "No" 1 "Yes" 9 "Missing" ;
label define C3A2_C    0 "No" 1 "Yes" 9 "Missing" ;
label define C3A3_C    0 "No" 1 "Yes" 9 "Missing" ;
label define C3A4_C    0 "No" 1 "Yes" 9 "Missing" ;
label define C3A5_C    0 "No" 1 "Yes" 9 "Missing" ;
label define C3A6_C    0 "No" 1 "Yes" 9 "Missing" ;
label define C3_1_C    0 "No" 1 "Yes" 9 "Missing" ;
label define C3_2_C    0 "No" 1 "Yes" 9 "Missing" ;
label define C3_3_C    0 "No" 1 "Yes" 9 "Missing" ;
label define C3_4_C    0 "No" 1 "Yes" 9 "Missing" ;
label define C3_5_C    0 "No" 1 "Yes" 9 "Missing" ;
label define C3_6_C    0 "No" 1 "Yes" 9 "Missing" ;
label define CATAGE    1 "12 to 17" 2 "18 to 25" 3 "26 to 34" 4 "35 or more"
                       9 "Missing" ;
label define CATAGE1C  1 "12-25 years" 2 "26-34 years" 3 "35+ years"
                       9 "Missing" ;
label define CIGFLAG   0 "No" 1 "Yes" 9 "Missing" ;
label define CIGMON    0 "No" 1 "Yes" 9 "Missing" ;
label define CIGYR     0 "No" 1 "Yes" 9 "Missing" ;
label define CJDFLAG   0 "No" 1 "Yes" 9 "Missing" ;
label define CJDYR     0 "No" 1 "Yes" 9 "Missing" ;
label define CLEANWYR  0 "No" 1 "Yes" 9 "Missing" ;
label define COCFLAG   0 "No" 1 "Yes" 9 "Missing" ;
label define COCMON    0 "No" 1 "Yes" 9 "Missing" ;
label define COCYR     0 "No" 1 "Yes" 9 "Missing" ;
label define COMFLAG   0 "No" 1 "Yes" 9 "Missing" ;
label define COOFLAG   0 "No" 1 "Yes" 9 "Missing" ;
label define COOMON    0 "No" 1 "Yes" 9 "Missing" ;
label define COOUIS    -8.00 "Missing" .00 "None" ;
label define COOYR     0 "No" 1 "Yes" 9 "Missing" ;
label define COUNSANY  1 "1-30 days" 2 "31-182 days" 3 "183+ days"
                       9 "Missing/not applicable" ;
label define COUNSMON  0 "No" 1 "Yes" 9 "Missing" ;
label define COUNSYR   0 "No" 1 "Yes" 9 "Missing" ;
label define CRIFLAG   0 "No" 1 "Yes" 9 "Missing" ;
label define CRKFLAG   0 "No" 1 "Yes" 9 "Missing" ;
label define CRKMON    0 "No" 1 "Yes" 9 "Missing" ;
label define CRKUIS    -8.00 "Missing" .00 "None" ;
label define CRKYR     0 "No" 1 "Yes" 9 "Missing" ;
label define D1F_C     1 "Still in treatment" 2 "Successful termination"
                       3 "Problem with program" 4 "Relapse" 5 "Other"
                       9 "Missing/not applicable" ;
label define D1_C      1 "Never" 2 "1-3 times" 3 "More than times"
                       9 "Missing" ;
label define DAYSTAT   -8 "Missing" ;
label define DAYSTAT1  0 "No" 1 "Yes" ;
label define DCSAMP    1 "DC" 2 "NON DC" ;
label define DPRSUM    0 "None" 9 "Missing" ;
label define DPRSUM_C  1 "None" 2 "1-2 problems and ANYYR=1"
                       3 "3-4 problems and ANYYR=1"
                       4 "5-6 problems and ANYYR=1" 9 "Missing" ;
label define DRUGFRST  0 "No" 1 "Yes" 9 "Missing" ;
label define EDUCAT1C  1 "Less than high school education"
                       2 "High school graduate" 3 "Any college"
                       4 "Not applicable" 9 "Missing" ;
label define EDUCCAT   1 "Less than high school education"
                       2 "High school graduate" 3 "Some college"
                       4 "College graduate" 5 "Not applicable" 9 "Missing" ;
label define ELSEANY   1 "Yes" 2 "No" 9 "Missing" ;
label define ELSEGRP   1 "0" 2 "1 to 13" 3 "14 to 26" 4 "27 to 39"
                       5 "40 to 52" 9 "Missing" ;
label define EMPL_MON  0 "No" 1 "Yes" 9 "Missing" ;
label define EMPSTAT   1 "Working full-time" 2 "Working part-time"
                       3 "Unemployed" 4 "Other" 5 "Not applicable"
                       9 "Missing" ;
label define EMPYRF    0 "No" 1 "Yes" ;
label define EXPALL    -8 "Missing" 0 "No expenses" 999 "$999 or more" ;
label define EXPILL    -8 "Missing" 0 "None" 999 "$999 or more" ;
label define EXPLEG    -8 "Missing" 0 "None" 999 "$999 or more" ;
label define F7A_MON   0 "No" 1 "Yes" 9 "Missing" ;
label define F7A_YR    0 "No" 1 "Yes" 9 "Missing" ;
label define F8B_C     1 "Private doctor/health clinic" 2 "Outpatient clinic"
                       3 "Public community health clinic"
                       4 "Shelter clinic/mobile outreach" 5 "Other"
                       6 "No visit" 9 "Missing" ;
label define F8_MON    0 "No" 1 "Yes" 9 "Missing" ;
label define F8_YR     0 "No" 1 "Yes" 9 "Missing" ;
label define GNDLOTHR  0 "No" 1 "Yes" 9 "Missing" ;
label define GRQFLAG   0 "No" 1 "Yes" 9 "Missing" ;
label define GRQYR     0 "No" 1 "Yes" 9 "Missing" ;
label define H1B_C1    0 "No" 1 "Yes" ;
label define H1B_C2    1 "None" 2 "1 to 3" 3 "More than 3" ;
label define H1C_C     1 "None" 2 "1 to 13 weeks" 3 "14 to 26 weeks"
                       4 "27 to 39 weeks" 5 "40 to 52 weeks" 9 "Missing" ;
label define H1N_C     0 "No" 1 "Yes" 9 "Missing" ;
label define H2_C      1 "Working full-time" 2 "Working part-time"
                       3 "Unemployed and looking for work"
                       4 "Unemployed and not looking for work"
                       5 "In school only" 6 "Retired"
                       7 "Disabled, not able to work" 8 "Other" 9 "Missing" ;
label define HALFLAG   0 "No" 1 "Yes" 9 "Missing" ;
label define HALMON    0 "No" 1 "Yes" 9 "Missing" ;
label define HALUIS    -8.00 "Missing" .00 "None" ;
label define HALYR     0 "No" 1 "Yes" 9 "Missing" ;
label define HERFLAG   0 "No" 1 "Yes" 9 "Missing" ;
label define HERMON    0 "No" 1 "Yes" 9 "Missing" ;
label define HERUIS    -8.00 "Missing" .00 "None" ;
label define HERYR     0 "No" 1 "Yes" 9 "Missing" ;
label define HMLFLAG   0 "No" 1 "Yes" 9 "Missing" ;
label define HMLYR     0 "No" 1 "Yes" 9 "Missing" ;
label define HOMAGE    1 "Never homeless" 2 "Under 26 years" 3 "26-34 years"
                       4 "35+ years" 9 "Unknown" ;
label define HOMDAYS   -9 "Legitimate skip" -8 "Missing"
                       9999 "Over 1825 days" ;
label define HOMFLAG   0 "No" 1 "Yes" ;
label define HOMLAST   -9 "Legitimate skip" -8 "Missing" -3 "Not applicable"
                       0 "None" 9999 "Over 1825 days" ;
label define HOMLGTH   1 "Never homeless" 2 "Less than 6 months"
                       3 "6 or more months" 9 "Unknown" ;
label define HOMLIT    0 "No" 1 "Yes" ;
label define HOMLSTC1  1 "Yes" 2 "No" ;
label define HOMLSTC2  0 "No" 1 "Yes" ;
label define HOMSTG    1 "Newly homeless" 2 "Chronically homeless"
                       3 "Intermittently homeless" 4 "At risk"
                       5 "Historically at risk" 6 "Intermittently at risk" ;
label define HOMSTG_C  1 "Newly homeless" 2 "Chronically homeless"
                       3 "Intermittently homeless" 4 "At risk" ;
label define HOMTMS    1 "Never homeless" 2 "1 time" 3 "2+ times" 9 "Missing" ;
label define HOUFLAG   0 "No" 1 "Yes" 9 "Missing" ;
label define HOUYR     0 "No" 1 "Yes" 9 "Missing" ;
label define HRS_MON   1 "None" 2 "1-34 hours" 3 "35 hours or more"
                       9 "Missing" ;
label define HVYDRK    0 "No" 1 "Yes" 9 "Missing" ;
label define HVYMON    0 "No" 1 "Yes" 9 "Missing" ;
label define HVYUIS    -8.00 "Missing" .00 "None" ;
label define IEMCRKYR  0 "No" 1 "Yes" 9 "Missing" ;
label define IEMFLAG   0 "No" 1 "Yes" 9 "Missing" ;
label define IEMMON    0 "No" 1 "Yes" 9 "Missing" ;
label define IEMYR     0 "No" 1 "Yes" 9 "Missing" ;
label define INCALL    -8 "Missing" 0 "None" 999 "$999 or more" ;
label define INCEB     -8 "Missing" 0 "None" 999 "$999 or more" ;
label define INCERN    -8 "Missing" 0 "None" 999 "$999 or more" ;
label define INCFLAG   0 "No" 1 "Yes" 9 "Missing" ;
label define INCILL    -8 "Missing" 0 "None" 999 "$999 or more" ;
label define INCLEG    -8 "Missing" 0 "None" 999 "$999 or more" ;
label define INCOEN    -8 "Missing" 0 "None" 999 "$999 or more" ;
label define INCOTH    -8 "Missing" 0 "None" 999 "$999 or more" ;
label define INCYR     0 "No" 1 "Yes" 9 "Missing" ;
label define INHFLAG   0 "No" 1 "Yes" 9 "Missing" ;
label define INHMON    0 "No" 1 "Yes" 9 "Missing" ;
label define INHUIS    -8.00 "Missing" .00 "None" ;
label define INHYR     0 "No" 1 "Yes" 9 "Missing" ;
label define INJCOC    0 "No" 1 "Yes" 9 "Missing" ;
label define INJHER    0 "No" 1 "Yes" 9 "Missing" ;
label define INJPSY    0 "No" 1 "Yes" 9 "Missing" ;
label define INSANY    0 "No" 1 "Yes" 9 "Missing" ;
label define INSFLAG   0 "No" 1 "Yes" ;
label define INSPRI    0 "No" 1 "Yes" 9 "Missing" ;
label define INSPRTX   0 "No" 1 "Yes" 9 "Missing" ;
label define INSPUB    0 "No" 1 "Yes" 9 "Missing" ;
label define INSPUTX   0 "No" 1 "Yes" 9 "Missing" ;
label define INSYR     0 "No" 1 "Yes" ;
label define LOCATION  1 "DC" 2 "Maryland" 3 "Virginia" ;
label define LOCLTS1   1 "DC MSA" 2 "Outside DC MSA" 9 "Unknown" ;
label define LOCPCE1   1 "DC MSA" 2 "Outside DC MSA" 9 "Unknown" ;
label define LOCPN1    1 "DC MSA" 2 "Outside DC MSA" 9 "Unknown" ;
label define MARSTAT   1 "Single" 2 "Married" 3 "Divorced or widowed"
                       9 "Missing" ;
label define MCKANY    0 "No" 1 "Yes" ;
label define MCKFAM    0 "No" 1 "Yes" 9 "Missing" ;
label define MCKILL    0 "No" 1 "Yes" 9 "Missing" ;
label define MCKUN     -8 "Missing" -3 "Not applicable" 0 "No" 1 "Yes" ;
label define MCKVET    0 "No" 1 "Yes" 9 "Missing" ;
label define MCKYOU    0 "No" 1 "Yes" 9 "Missing" ;
label define METFLAG   0 "No" 1 "Yes" 9 "Missing" ;
label define METMON    0 "No" 1 "Yes" 9 "Missing" ;
label define METUIS    -8.00 "Missing" .00 "None" ;
label define METYR     0 "No" 1 "Yes" 9 "Missing" ;
label define MHSM30_C  1 "None" 2 "1 to 3" 3 "4 to 6" 4 "7 to 9" 9 "Missing" ;
label define MHSUM     -8 "Missing" 0 "None" ;
label define MHSUM30   -8 "Missing" 0 "None" ;
label define MHSUM_C   1 "None" 2 "1 to 3" 3 "4 to 6" 4 "7 to 9" 9 "Missing" ;
label define MHTX30    0 "No" 1 "Yes" 9 "Missing" ;
label define MHTXFL    0 "No" 1 "Yes" 9 "Missing" ;
label define MRJFLAG   0 "No" 1 "Yes" 9 "Missing" ;
label define MRJMON    0 "No" 1 "Yes" 9 "Missing" ;
label define MRJUIS    -8.00 "Missing" .00 "None" ;
label define MRJYR     0 "No" 1 "Yes" 9 "Missing" ;
label define NDLFLAG   0 "No" 1 "Yes" 9 "Missing" ;
label define NDLMON    0 "No" 1 "Yes" 9 "Missing" ;
label define NDLYR     0 "No" 1 "Yes" 9 "Missing" ;
label define NETALL    -8888 "Missing" -999 "-$999 or less"
                       9999 "$9999 or greater" ;
label define NETERN    -8888 "Missing" -999 "-$999 or less"
                       9999 "$9999 or greater" ;
label define NETILL    -8888 "Missing" -999 "-$999 or less"
                       9999 "$9999 or greater" ;
label define NETLEG    -8888 "Missing" -999 "-$999 or less"
                       9999 "$9999 or greater" ;
label define NPSNDLYR  1 "None" 2 "1 person" 3 "2+ people" 9 "Missing" ;
label define OINFLAG   0 "No" 1 "Yes" ;
label define OINYR     0 "No" 1 "Yes" ;
label define OTHRLA    0 "No" 1 "Yes" 9 "Missing" ;
label define OTHRTCD   0 "No" 1 "Yes" 9 "Missing" ;
label define OTHRUWA   0 "No" 1 "Yes" 9 "Missing" ;
label define OTHRWS    0 "No" 1 "Yes" 9 "Missing" ;
label define OWNANY    1 "Yes" 2 "No" 9 "Missing" ;
label define OWNGRP    2 "1 to 13" 3 "14 to 26" 4 "27 to 39" 5 "40 to 52"
                       9 "Missing" ;
label define PATFLAG   -8 "Missing" 1 "Cocaine only" 2 "Marijuana only"
                       3 "Cocaine and marijuana only"
                       5 "Cocaine, heroin, marijuana, psychotherap"
                       6 "Cocaine, marijuana, and other only"
                       7 "Cocaine, heroin, marijuana, and other on"
                       8 "Cocaine, marijuana, psychotherapeutics,"
                       9 "Cocaine, marijuana, and psychotherapeuti"
                       10 "Marijuana and other only"
                       11 "Marijuana, psychotherapeutics, and other"
                       12 "Marijuana and psychotherapeutics only"
                       13 "Cocaine, heroin, and marijuana only"
                       14 "Other only"
                       15 "Cocaine, heroin, marijuana, and psychoth"
                       32 "All other patterns consisting of at leas"
                       64 "No drug use" ;
label define PATFLAG3  1 "Heroin user" 2 "Cocaine user" 3 "Other drug user"
                       4 "Marijuana drug user" 5 "Nonuser" 9 "Missing" ;
label define PATMON    -8 "Missing" 1 "Cocaine only" 2 "Marijuana only"
                       3 "Cocaine and marijuana only"
                       4 "Cocaine and heroin only"
                       32 "All other patterns consisting of at leas"
                       64 "No drug use" ;
label define PATMON3   1 "Heroin user" 2 "Cocaine user" 3 "Other drug user"
                       4 "Marijuana drug user" 5 "Nonuser" 9 "Missing" ;
label define PATYR     -8 "Missing" 1 "Cocaine only" 2 "Marijuana only"
                       3 "Cocaine and marijuana only"
                       4 "Cocaine and heroin only"
                       5 "Cocaine, heroin, marijuana, psychotherap"
                       6 "Cocaine, marijuana, and other only"
                       9 "Cocaine, marijuana, and psychotherapeuti"
                       12 "Marijuana and psychotherapeutics only"
                       13 "Cocaine, heroin, and marijuana only"
                       15 "Cocaine, heroin, marijuana, and psychoth"
                       16 "Cocaine, heroin, and psychotherapeutics"
                       17 "Psychotherapeutics only"
                       32 "All other patterns consisting of at leas"
                       64 "No drug use" ;
label define PATYR3    1 "Heroin user" 2 "Cocaine user" 3 "Other drug user"
                       4 "Marijuana drug user" 5 "Nonuser" 9 "Missing" ;
label define PCPDRG    0 "None" 9 "Missing" ;
label define PCPILL    0 "None" 9 "Missing" ;
label define PCPSUM    -8 "Missing" 0 "None" ;
label define PCPSUM_C  1 "None" 2 "1 to 3" 3 "4+" 9 "Missing" ;
label define POVIG     -8 "Missing" ;
label define POVIND_C  1 "Above poverty line" 2 "51%-100%" 3 "26%-50%"
                       4 "0%-25%" 9 "Missing" ;
label define POVNP     -8 "Missing" ;
label define PRGFLAG   -8 "Missing" -3 "Not applicable" 0 "No" 1 "Yes" ;
label define PRGYR     -8 "Missing" -3 "Not applicable" 0 "No" 1 "Yes" ;
label define PSYFLAG   0 "No" 1 "Yes" 9 "Missing" ;
label define PSYMON    0 "No" 1 "Yes" 9 "Missing" ;
label define PSYYR     0 "No" 1 "Yes" 9 "Missing" ;
label define RACE      1 "White" 2 "Black" 3 "Hispanic and all other"
                       9 "Missing" ;
label define SDFLAG    -8 "Missing" -3 "Not applicable" 0 "No" 1 "Yes" ;
label define SERDAY    1 "Shelter only" 2 "Soup kitchen only" 3 "Both"
                       4 "Neither" ;
label define SERFLAG   1 "Shelter only" 2 "Soup kitchen only" 3 "Both"
                       4 "Neither" ;
label define SERFL_C   1 "Yes" 2 "No" ;
label define SERMON    1 "Shelter only" 2 "Soup kitchen only" 3 "Both"
                       4 "Neither" ;
label define SERMON_C  1 "Yes" 2 "No" ;
label define SEX       1 "Male" 2 "Female" ;
label define SHOOTGYR  0 "No" 1 "Yes" 9 "Missing" ;
label define SKMEAL    1 "Breakfast" 2 "Lunch" 3 "Dinner" 4 "Food bank"
                       9 "Missing/not applicable" ;
label define SKSIT     1 "Single sitting" 2 "Multiple sittings"
                       3 "Mobile unit" 4 "Flow-type food bank" 9 "Missing" ;
label define STAFLAG   0 "No" 1 "Yes" 9 "Missing" ;
label define STAMON    0 "No" 1 "Yes" 9 "Missing" ;
label define STAUIS    -8.00 "Missing" .00 "None" ;
label define STAYR     0 "No" 1 "Yes" 9 "Missing" ;
label define STMFLAG   0 "No" 1 "Yes" 9 "Missing" ;
label define STMMON    0 "No" 1 "Yes" 9 "Missing" ;
label define STMUIS    -8.00 "Missing" .00 "None" ;
label define STMYR     0 "No" 1 "Yes" 9 "Missing" ;
label define TXFLAG    0 "No" 1 "Yes" 9 "Missing" ;
label define TXYR      0 "No" 1 "Yes" 9 "Missing" ;
label define UOLDNDL   0 "No" 1 "Yes" 9 "Missing" ;
label define WKCOR     -8 "Missing" 0 "None" ;
label define WKELSE    -8 "Missing" 0 "None" ;
label define WKGQ      -8 "Missing" 0 "None" ;
label define WKHOU     -8 "Missing" 0 "None" ;
label define WKNUR     -8 "Missing" 0 "None" ;
label define WKOS      -8 "Missing" 0 "None" ;
label define WKSH      -8 "Missing" 0 "None" ;
label define WKST      -8 "Missing" 0 "None" ;
label define WKSUM     -8 "Missing" 0 "None" ;
label define WKTXF     -8 "Missing" 0 "None" ;
label define ZSAMLOC   1 "Street block" 2 "Shelter" 3 "Soup kitchen meal"
                       4 "Encampment cluster" ;
label define ZURBAN    1 "Inner city" 2 "Other urban" 3 "Rural" ;
label define H1A_C     -8 "Missing" 1 "Professional/technical" 2 "Sales"
                       3 "Clerical/office" 4 "Craft/skilled labor"
                       5 "Machine/transportation operative"
                       6 "Nonfarm laborer" 7 "Service worker"
                       8 "Farm owner/manager" 9 "Military service" 10 "Other"
                       11 "Never worked" ;
label define POVIND    -8.0000 "Missing" ;


#delimit cr


/***************************************************************************

 Section 4: Missing Values

 This section will replace numeric missing values (i.e., -9) with generic
 system missing ".".  By default the code in this section is commented out.
 Users wishing to apply the generic missing values should remove the comment
 at the beginning and end of this section.  Note that Stata allows you to
 specify up to 27 unique missing value codes.

****************************************************************/

/*
replace A2 = . if (A2 <= -1 )
replace A3 = . if (A3 <= -1 )
replace A4D = . if (A4D <= -1 )
replace A4W = . if (A4W <= -1 )
replace A4M = . if (A4M <= -1 )
replace A4Y = . if (A4Y <= -1 )
replace A4AD = . if (A4AD <= -1 )
replace A4AW = . if (A4AW <= -1 )
replace A4AM = . if (A4AM <= -1 )
replace A4AY = . if (A4AY <= -1 )
replace A5 = . if (A5 <= -1 )
replace A6A = . if (A6A <= -1 )
replace A9 = . if (A9 <= -1 )
replace A10 = . if (A10 <= -1 )
replace A10A = . if (A10A <= -1 )
replace A11 = . if (A11 <= -1 )
replace A11A = . if (A11A <= -1 )
replace B1 = . if (B1 <= -1 )
replace B1A = . if (B1A <= -1 )
replace B1B = . if (B1B <= -1 )
replace B1C = . if (B1C <= -1 )
replace B2 = . if (B2 <= -1 )
replace B2A = . if (B2A <= -1 )
replace B2B = . if (B2B <= -1 )
replace B2C = . if (B2C <= -1 )
replace B2D = . if (B2D <= -1 )
replace B2E = . if (B2E <= -1 )
replace B3 = . if (B3 <= -1 )
replace B3A = . if (B3A <= -1 )
replace B3B = . if (B3B <= -1 )
replace B3C = . if (B3C <= -1 )
replace B3D = . if (B3D <= -1 )
replace B4 = . if (B4 <= -1 )
replace B4A = . if (B4A <= -1 )
replace B4B = . if (B4B <= -1 )
replace B4C = . if (B4C <= -1 )
replace B5 = . if (B5 <= -1 )
replace B5A = . if (B5A <= -1 )
replace B5B = . if (B5B <= -1 )
replace B5C = . if (B5C <= -1 )
replace B5D = . if (B5D <= -1 )
replace B6 = . if (B6 <= -1 )
replace B6A = . if (B6A <= -1 )
replace B6B = . if (B6B <= -1 )
replace B6C = . if (B6C <= -1 )
replace B6D = . if (B6D <= -1 )
replace B6E1 = . if (B6E1 <= -1 )
replace B6E2 = . if (B6E2 <= -1 )
replace B6E3 = . if (B6E3 <= -1 )
replace B6E4 = . if (B6E4 <= -1 )
replace B6E5 = . if (B6E5 <= -1 )
replace B7 = . if (B7 <= -1 )
replace B7A = . if (B7A <= -1 )
replace B7B = . if (B7B <= -1 )
replace B7C = . if (B7C <= -1 )
replace B8 = . if (B8 <= -1 )
replace B8A = . if (B8A <= -1 )
replace B8B = . if (B8B <= -1 )
replace B8C = . if (B8C <= -1 )
replace B8D1 = . if (B8D1 <= -1 )
replace B8D2 = . if (B8D2 <= -1 )
replace B8D3 = . if (B8D3 <= -1 )
replace B8D4 = . if (B8D4 <= -1 )
replace B8D5 = . if (B8D5 <= -1 )
replace B9 = . if (B9 <= -1 )
replace B9A = . if (B9A <= -1 )
replace B9B = . if (B9B <= -1 )
replace B9C = . if (B9C <= -1 )
replace B10 = . if (B10 <= -1 )
replace B10A = . if (B10A <= -1 )
replace B10B = . if (B10B <= -1 )
replace B10C = . if (B10C <= -1 )
replace B11 = . if (B11 <= -1 )
replace B11A = . if (B11A <= -1 )
replace B11B = . if (B11B <= -1 )
replace B11C = . if (B11C <= -1 )
replace B12_1 = . if (B12_1 <= -1 )
replace B12_2 = . if (B12_2 <= -1 )
replace B12_3 = . if (B12_3 <= -1 )
replace C1_1 = . if (C1_1 <= -1 )
replace C1_2 = . if (C1_2 <= -1 )
replace C1_3 = . if (C1_3 <= -1 )
replace C1_4 = . if (C1_4 <= -1 )
replace C1_5 = . if (C1_5 <= -1 )
replace C1_6 = . if (C1_6 <= -1 )
replace C1_7 = . if (C1_7 <= -1 )
replace C1_8 = . if (C1_8 <= -1 )
replace C1_9 = . if (C1_9 <= -1 )
replace C1_10 = . if (C1_10 <= -1 )
replace C1_11 = . if (C1_11 <= -1 )
replace C1_12 = . if (C1_12 <= -1 )
replace C1_13 = . if (C1_13 <= -1 )
replace C1_14 = . if (C1_14 <= -1 )
replace C1_91 = . if (C1_91 <= -1 )
replace C1_92 = . if (C1_92 <= -1 )
replace C2 = . if (C2 <= -1 )
replace C2A1 = . if (C2A1 <= -1 )
replace C2A2 = . if (C2A2 <= -1 )
replace C2A3 = . if (C2A3 <= -1 )
replace C2A4 = . if (C2A4 <= -1 )
replace C2A5 = . if (C2A5 <= -1 )
replace C2A6 = . if (C2A6 <= -1 )
replace C2A7 = . if (C2A7 <= -1 )
replace C2A8 = . if (C2A8 <= -1 )
replace C2A9 = . if (C2A9 <= -1 )
replace C2A10 = . if (C2A10 <= -1 )
replace C2A11 = . if (C2A11 <= -1 )
replace C2A12 = . if (C2A12 <= -1 )
replace C2A13 = . if (C2A13 <= -1 )
replace C2A14 = . if (C2A14 <= -1 )
replace C2B = . if (C2B <= -1 )
replace C2C = . if (C2C <= -1 )
replace C2D = . if (C2D <= -1 )
replace C2E = . if (C2E <= -1 )
replace C2F = . if (C2F <= -1 )
replace C2G = . if (C2G <= -1 )
replace C2H = . if (C2H <= -1 )
replace C2I = . if (C2I <= -1 )
replace C3_1 = . if (C3_1 <= -1 )
replace C3_2 = . if (C3_2 <= -1 )
replace C3_3 = . if (C3_3 <= -1 )
replace C3_4 = . if (C3_4 <= -1 )
replace C3_5 = . if (C3_5 <= -1 )
replace C3_6 = . if (C3_6 <= -1 )
replace C3A1 = . if (C3A1 <= -1 )
replace C3A2 = . if (C3A2 <= -1 )
replace C3A3 = . if (C3A3 <= -1 )
replace C3A4 = . if (C3A4 <= -1 )
replace C3A5 = . if (C3A5 <= -1 )
replace C3A6 = . if (C3A6 <= -1 )
replace C4A = . if (C4A <= -1 )
replace C4B = . if (C4B <= -1 )
replace C4C = . if (C4C <= -1 )
replace C4D = . if (C4D <= -1 )
replace C4E = . if (C4E <= -1 )
replace C4F = . if (C4F <= -1 )
replace C4G = . if (C4G <= -1 )
replace C4H = . if (C4H <= -1 )
replace C4I = . if (C4I <= -1 )
replace C4J = . if (C4J <= -1 )
replace C4K = . if (C4K <= -1 )
replace C4L = . if (C4L <= -1 )
replace C5_1 = . if (C5_1 <= -1 )
replace C5_2 = . if (C5_2 <= -1 )
replace C5_3 = . if (C5_3 <= -1 )
replace C5_4 = . if (C5_4 <= -1 )
replace C5_5 = . if (C5_5 <= -1 )
replace C5_6 = . if (C5_6 <= -1 )
replace C5_7 = . if (C5_7 <= -1 )
replace C5_8 = . if (C5_8 <= -1 )
replace C5_9 = . if (C5_9 <= -1 )
replace C5_10 = . if (C5_10 <= -1 )
replace C5_11 = . if (C5_11 <= -1 )
replace C5_12 = . if (C5_12 <= -1 )
replace C5_13 = . if (C5_13 <= -1 )
replace C5_14 = . if (C5_14 <= -1 )
replace C5_91 = . if (C5_91 <= -1 )
replace C5_94 = . if (C5_94 <= -1 )
replace C6_1 = . if (C6_1 <= -1 )
replace C6_2 = . if (C6_2 <= -1 )
replace C6_3 = . if (C6_3 <= -1 )
replace C6_4 = . if (C6_4 <= -1 )
replace C6_5 = . if (C6_5 <= -1 )
replace C6_6 = . if (C6_6 <= -1 )
replace C6_7 = . if (C6_7 <= -1 )
replace C6_8 = . if (C6_8 <= -1 )
replace C6_9 = . if (C6_9 <= -1 )
replace C6_10 = . if (C6_10 <= -1 )
replace C6_11 = . if (C6_11 <= -1 )
replace C6_12 = . if (C6_12 <= -1 )
replace C6_13 = . if (C6_13 <= -1 )
replace C6_14 = . if (C6_14 <= -1 )
replace C6_91 = . if (C6_91 <= -1 )
replace C7_1 = . if (C7_1 <= -1 )
replace C7_2 = . if (C7_2 <= -1 )
replace C7_3 = . if (C7_3 <= -1 )
replace C7_4 = . if (C7_4 <= -1 )
replace C7_5 = . if (C7_5 <= -1 )
replace C7_6 = . if (C7_6 <= -1 )
replace C7_7 = . if (C7_7 <= -1 )
replace C7_8 = . if (C7_8 <= -1 )
replace C7_9 = . if (C7_9 <= -1 )
replace C7_10 = . if (C7_10 <= -1 )
replace C7_11 = . if (C7_11 <= -1 )
replace C7_12 = . if (C7_12 <= -1 )
replace C7_13 = . if (C7_13 <= -1 )
replace C7_14 = . if (C7_14 <= -1 )
replace C7_91 = . if (C7_91 <= -1 )
replace C8_93 = . if (C8_93 <= -1 )
replace C8A = . if (C8A <= -1 )
replace C8B = . if (C8B <= -1 )
replace C8C = . if (C8C <= -1 )
replace C8D = . if (C8D <= -1 )
replace C8E = . if (C8E <= -1 )
replace C8F = . if (C8F <= -1 )
replace C8G = . if (C8G <= -1 )
replace C8H = . if (C8H <= -1 )
replace C8I = . if (C8I <= -1 )
replace C9_93 = . if (C9_93 <= -1 )
replace C9A = . if (C9A <= -1 )
replace C9B = . if (C9B <= -1 )
replace C9C = . if (C9C <= -1 )
replace C9D = . if (C9D <= -1 )
replace C9E = . if (C9E <= -1 )
replace C9F = . if (C9F <= -1 )
replace D1 = . if (D1 <= -1 )
replace D1A = . if (D1A <= -1 )
replace D1B1 = . if (D1B1 <= -1 )
replace D1B2 = . if (D1B2 <= -1 )
replace D1B3 = . if (D1B3 <= -1 )
replace D1B4 = . if (D1B4 <= -1 )
replace D1B5 = . if (D1B5 <= -1 )
replace D1B6 = . if (D1B6 <= -1 )
replace D1B7 = . if (D1B7 <= -1 )
replace D1B8 = . if (D1B8 <= -1 )
replace D1B9 = . if (D1B9 <= -1 )
replace D1B10 = . if (D1B10 <= -1 )
replace D1B11 = . if (D1B11 <= -1 )
replace D1B12 = . if (D1B12 <= -1 )
replace D1B13 = . if (D1B13 <= -1 )
replace D1B14 = . if (D1B14 <= -1 )
replace D1C1 = . if (D1C1 <= -1 )
replace D1C2 = . if (D1C2 <= -1 )
replace D1C3 = . if (D1C3 <= -1 )
replace D1C4 = . if (D1C4 <= -1 )
replace D1C5 = . if (D1C5 <= -1 )
replace D1C6 = . if (D1C6 <= -1 )
replace D1C7 = . if (D1C7 <= -1 )
replace D1C8 = . if (D1C8 <= -1 )
replace D1C9 = . if (D1C9 <= -1 )
replace D1C10 = . if (D1C10 <= -1 )
replace D1C11 = . if (D1C11 <= -1 )
replace D1C12 = . if (D1C12 <= -1 )
replace D1C13 = . if (D1C13 <= -1 )
replace D1C14 = . if (D1C14 <= -1 )
replace D1C15 = . if (D1C15 <= -1 )
replace D1C16 = . if (D1C16 <= -1 )
replace D1C17 = . if (D1C17 <= -1 )
replace D1C18 = . if (D1C18 <= -1 )
replace D1C19 = . if (D1C19 <= -1 )
replace D1D = . if (D1D <= -1 )
replace D1E = . if (D1E <= -1 )
replace D1F = . if (D1F <= -1 )
replace E1A = . if (E1A <= -1 )
replace E1B = . if (E1B <= -1 )
replace E1C = . if (E1C <= -1 )
replace E1D = . if (E1D <= -1 )
replace E1E = . if (E1E <= -1 )
replace E2 = . if (E2 <= -1 )
replace E3 = . if (E3 <= -1 )
replace E4A = . if (E4A <= -1 )
replace E4B = . if (E4B <= -1 )
replace E5A = . if (E5A <= -1 )
replace E5B = . if (E5B <= -1 )
replace E6A = . if (E6A <= -1 )
replace E6B = . if (E6B <= -1 )
replace E7A = . if (E7A <= -1 )
replace E7B = . if (E7B <= -1 )
replace F1A = . if (F1A <= -1 )
replace F1B = . if (F1B <= -1 )
replace F1C = . if (F1C <= -1 )
replace F1D = . if (F1D <= -1 )
replace F2A = . if (F2A <= -1 )
replace F2B = . if (F2B <= -1 )
replace F2C = . if (F2C <= -1 )
replace F2D = . if (F2D <= -1 )
replace F2E = . if (F2E <= -1 )
replace F2F = . if (F2F <= -1 )
replace F3 = . if (F3 <= -1 )
replace F3A_A = . if (F3A_A <= -1 )
replace F3A_B = . if (F3A_B <= -1 )
replace F3A_C = . if (F3A_C <= -1 )
replace F4 = . if (F4 <= -1 )
replace F4A = . if (F4A <= -1 )
replace F4B = . if (F4B <= -1 )
replace F4C = . if (F4C <= -1 )
replace F4D = . if (F4D <= -1 )
replace F4D1 = . if (F4D1 <= -1 )
replace F4E1 = . if (F4E1 <= -1 )
replace F4D2 = . if (F4D2 <= -1 )
replace F4E2 = . if (F4E2 <= -1 )
replace F4D3 = . if (F4D3 <= -1 )
replace F4E3 = . if (F4E3 <= -1 )
replace F4D4 = . if (F4D4 <= -1 )
replace F4E4 = . if (F4E4 <= -1 )
replace F4D5 = . if (F4D5 <= -1 )
replace F4E5 = . if (F4E5 <= -1 )
replace F4D6 = . if (F4D6 <= -1 )
replace F4E6 = . if (F4E6 <= -1 )
replace F4D7 = . if (F4D7 <= -1 )
replace F4E7 = . if (F4E7 <= -1 )
replace F4D8 = . if (F4D8 <= -1 )
replace F4E8 = . if (F4E8 <= -1 )
replace F4D9 = . if (F4D9 <= -1 )
replace F4E9 = . if (F4E9 <= -1 )
replace F4D10 = . if (F4D10 <= -1 )
replace F4E10 = . if (F4E10 <= -1 )
replace F4D11 = . if (F4D11 <= -1 )
replace F4E11 = . if (F4E11 <= -1 )
replace F5 = . if (F5 <= -1 )
replace F5A1 = . if (F5A1 <= -1 )
replace F5A2 = . if (F5A2 <= -1 )
replace F5A3 = . if (F5A3 <= -1 )
replace F5A4 = . if (F5A4 <= -1 )
replace F5A5 = . if (F5A5 <= -1 )
replace F5B = . if (F5B <= -1 )
replace F5C1 = . if (F5C1 <= -1 )
replace F5C2 = . if (F5C2 <= -1 )
replace F5C3 = . if (F5C3 <= -1 )
replace F5C4 = . if (F5C4 <= -1 )
replace F5C5 = . if (F5C5 <= -1 )
replace F5C5SP = . if (F5C5SP <= -1 )
replace F5D = . if (F5D <= -1 )
replace F6 = . if (F6 <= -1 )
replace F6A = . if (F6A <= -1 )
replace F6B = . if (F6B <= -1 )
replace F6C = . if (F6C <= -1 )
replace F7 = . if (F7 <= -1 )
replace F7A = . if (F7A <= -1 )
replace F7B = . if (F7B <= -1 )
replace F7C1 = . if (F7C1 <= -1 )
replace F7C2 = . if (F7C2 <= -1 )
replace F7C3 = . if (F7C3 <= -1 )
replace F8 = . if (F8 <= -1 )
replace F8A = . if (F8A <= -1 )
replace G1A = . if (G1A <= -1 )
replace G1B = . if (G1B <= -1 )
replace G2A = . if (G2A <= -1 )
replace G2B = . if (G2B <= -1 )
replace G3A = . if (G3A <= -1 )
replace G3B = . if (G3B <= -1 )
replace G4A = . if (G4A <= -1 )
replace G4B = . if (G4B <= -1 )
replace G5A = . if (G5A <= -1 )
replace G5B = . if (G5B <= -1 )
replace G6A = . if (G6A <= -1 )
replace G6B = . if (G6B <= -1 )
replace G7A = . if (G7A <= -1 )
replace G7B = . if (G7B <= -1 )
replace G8A = . if (G8A <= -1 )
replace G8B = . if (G8B <= -1 )
replace G9A = . if (G9A <= -1 )
replace G9B = . if (G9B <= -1 )
replace G10 = . if (G10 <= -1 )
replace G10A = . if (G10A <= -1 )
replace G10B = . if (G10B <= -1 )
replace G11 = . if (G11 <= -1 )
replace G11A = . if (G11A <= -1 )
replace G11B = . if (G11B <= -1 )
replace G12 = . if (G12 <= -1 )
replace G12A1 = . if (G12A1 <= -1 )
replace G12A2 = . if (G12A2 <= -1 )
replace G12A3 = . if (G12A3 <= -1 )
replace G12A4 = . if (G12A4 <= -1 )
replace G12A5 = . if (G12A5 <= -1 )
replace G12A6 = . if (G12A6 <= -1 )
replace G12A7 = . if (G12A7 <= -1 )
replace G12A8 = . if (G12A8 <= -1 )
replace G12A9 = . if (G12A9 <= -1 )
replace G12A10 = . if (G12A10 <= -1 )
replace G12A11 = . if (G12A11 <= -1 )
replace G12A12 = . if (G12A12 <= -1 )
replace G12A13 = . if (G12A13 <= -1 )
replace G12A14 = . if (G12A14 <= -1 )
replace G12A15 = . if (G12A15 <= -1 )
replace G12A16 = . if (G12A16 <= -1 )
replace G12A17 = . if (G12A17 <= -1 )
replace G12A18 = . if (G12A18 <= -1 )
replace G12A19 = . if (G12A19 <= -1 )
replace G12A20 = . if (G12A20 <= -1 )
replace G12A21 = . if (G12A21 <= -1 )
replace G12A22 = . if (G12A22 <= -1 )
replace G12A23 = . if (G12A23 <= -1 )
replace G12A24 = . if (G12A24 <= -1 )
replace G12A25 = . if (G12A25 <= -1 )
replace G12A26 = . if (G12A26 <= -1 )
replace G12A27 = . if (G12A27 <= -1 )
replace G12A28 = . if (G12A28 <= -1 )
replace G12A29 = . if (G12A29 <= -1 )
replace G12A29S = . if (G12A29S <= -1 )
replace H1MON = . if (H1MON <= -1 )
replace H1YR = . if (H1YR <= -1 )
replace H1N = . if (H1N <= -1 )
replace H1B = . if (H1B <= -1 )
replace H1C = . if (H1C <= -1 )
replace H1D = . if (H1D <= -1 )
replace H2 = . if (H2 <= -1 )
replace H3A = . if (H3A <= -1 )
replace H3B = . if (H3B <= -1 )
replace H4A = . if (H4A <= -1 )
replace H4B = . if (H4B <= -1 )
replace H5A = . if (H5A <= -1 )
replace H5B = . if (H5B <= -1 )
replace H6A = . if (H6A <= -1 )
replace H6B = . if (H6B <= -1 )
replace H7A = . if (H7A <= -1 )
replace H7B = . if (H7B <= -1 )
replace H8A = . if (H8A <= -1 )
replace H8B = . if (H8B <= -1 )
replace H9A = . if (H9A <= -1 )
replace H9B = . if (H9B <= -1 )
replace H10A = . if (H10A <= -1 )
replace H10B = . if (H10B <= -1 )
replace H11A = . if (H11A <= -1 )
replace H11B = . if (H11B <= -1 )
replace H12A = . if (H12A <= -1 )
replace H12B = . if (H12B <= -1 )
replace H13A = . if (H13A <= -1 )
replace H13B = . if (H13B <= -1 )
replace H14A = . if (H14A <= -1 )
replace H14B = . if (H14B <= -1 )
replace H14A_A = . if (H14A_A <= -1 )
replace H14A_B = . if (H14A_B <= -1 )
replace H14A_C = . if (H14A_C <= -1 )
replace H15A = . if (H15A <= -1 )
replace H15B = . if (H15B <= -1 )
replace H15C = . if (H15C <= -1 )
replace H15D = . if (H15D <= -1 )
replace H15E = . if (H15E <= -1 )
replace H16A = . if (H16A <= -1 )
replace H16B = . if (H16B <= -1 )
replace H16C = . if (H16C <= -1 )
replace H16D = . if (H16D <= -1 )
replace H16E = . if (H16E <= -1 )
replace H16E_A = . if (H16E_A <= -1 )
replace H16E_AA = . if (H16E_AA <= -1 )
replace H16E_B = . if (H16E_B <= -1 )
replace H16E_BB = . if (H16E_BB <= -1 )
replace I1A = . if (I1A <= -1 )
replace I1BM = . if (I1BM <= -1 )
replace I1BW = . if (I1BW <= -1 )
replace I2A = . if (I2A <= -1 )
replace I2BM = . if (I2BM <= -1 )
replace I2BW = . if (I2BW <= -1 )
replace I3A = . if (I3A <= -1 )
replace I3BM = . if (I3BM <= -1 )
replace I3BW = . if (I3BW <= -1 )
replace I4A = . if (I4A <= -1 )
replace I4BM = . if (I4BM <= -1 )
replace I4BW = . if (I4BW <= -1 )
replace I5A = . if (I5A <= -1 )
replace I5BM = . if (I5BM <= -1 )
replace I5BW = . if (I5BW <= -1 )
replace I6A = . if (I6A <= -1 )
replace I6BM = . if (I6BM <= -1 )
replace I6BW = . if (I6BW <= -1 )
replace I7A = . if (I7A <= -1 )
replace I7BM = . if (I7BM <= -1 )
replace I7BW = . if (I7BW <= -1 )
replace I8A = . if (I8A <= -1 )
replace I8BM = . if (I8BM <= -1 )
replace I8BW = . if (I8BW <= -1 )
replace I9A = . if (I9A <= -1 )
replace I9BM = . if (I9BM <= -1 )
replace I9BW = . if (I9BW <= -1 )
replace I9AA = . if (I9AA <= -1 )
replace I9AB = . if (I9AB <= -1 )
replace I9AC = . if (I9AC <= -1 )
replace I10 = . if (I10 <= -1 )
replace J1 = . if (J1 <= -1 )
replace AGE = . if (AGE <= -1 )
replace J2A = . if (J2A <= -1 )
replace J5 = . if (J5 <= -1 )
replace J5A = . if (J5A <= -1 )
replace J8_0 = . if (J8_0 <= -1 )
replace J8_1 = . if (J8_1 <= -1 )
replace J8_2 = . if (J8_2 <= -1 )
replace J8_3 = . if (J8_3 <= -1 )
replace J8_4 = . if (J8_4 <= -1 )
replace J8_5 = . if (J8_5 <= -1 )
replace J8_6 = . if (J8_6 <= -1 )
replace J8_7 = . if (J8_7 <= -1 )
replace J8_8 = . if (J8_8 <= -1 )
replace J8_9 = . if (J8_9 <= -1 )
replace J9 = . if (J9 <= -1 )
replace J9AY = . if (J9AY <= -1 )
replace J9AM = . if (J9AM <= -1 )
replace J10 = . if (J10 <= -1 )
replace J11 = . if (J11 <= -1 )
replace J12 = . if (J12 <= -1 )
replace K1 = . if (K1 <= -1 )
replace AW_A = . if (AW_A <= -1.0000 )
replace AWGAMA_A = . if (AWGAMA_A <= -1.0000 )
replace VESTR = . if (VESTR <= -1 )
replace VEREP = . if (VEREP <= -1 )
replace ADMFLAG = . if (ADMFLAG == 9)
replace ALCFLAG = . if (ALCFLAG == 9)
replace ALCMON = . if (ALCMON == 9)
replace ALCUIS = . if (ALCUIS <= -1.00 )
replace ALCUSE = . if (ALCUSE == 9)
replace ALCUSEHV = . if (ALCUSEHV == 9)
replace ALCYR = . if (ALCYR == 9)
replace ALPRSM_C = . if (ALPRSM_C == 9)
replace ALPRSUM = . if (ALPRSUM <= -1 )
replace ANYAGE = . if (ANYAGE <= -1 )
replace ANYAGE21 = . if (ANYAGE21 == 9)
replace ANYFLAG = . if (ANYFLAG == 9)
replace ANYLA = . if (ANYLA == 9)
replace ANYLOSS = . if (ANYLOSS == 9)
replace ANYMON = . if (ANYMON == 9)
replace ANYTCD = . if (ANYTCD == 9)
replace ANYUSE = . if (ANYUSE == 9)
replace ANYUWA = . if (ANYUWA == 9)
replace ANYWS = . if (ANYWS == 9)
replace ANYYR = . if (ANYYR == 9)
replace ARRFLAG = . if (ARRFLAG == 9)
replace B2C_A = . if (B2C_A <= -1 )
replace B2C_AC = . if (B2C_AC == 9)
replace B2E_A = . if (B2E_A <= -1 )
replace B2E_AC = . if (B2E_AC == 9)
replace B3C_A = . if (B3C_A <= -1 )
replace B3C_AC = . if (B3C_AC == 9)
replace B5C_A = . if (B5C_A <= -1 )
replace B5C_AC = . if (B5C_AC == 9)
replace B6C_A = . if (B6C_A <= -1 )
replace B6C_AC = . if (B6C_AC == 9)
replace B8C_A = . if (B8C_A <= -1 )
replace B8C_AC = . if (B8C_AC == 9)
replace BD_AGE_E = . if (BD_AGE_E <= -1 )
replace C3A1_C = . if (C3A1_C == 9)
replace C3A2_C = . if (C3A2_C == 9)
replace C3A3_C = . if (C3A3_C == 9)
replace C3A4_C = . if (C3A4_C == 9)
replace C3A5_C = . if (C3A5_C == 9)
replace C3A6_C = . if (C3A6_C == 9)
replace C3_1_C = . if (C3_1_C == 9)
replace C3_2_C = . if (C3_2_C == 9)
replace C3_3_C = . if (C3_3_C == 9)
replace C3_4_C = . if (C3_4_C == 9)
replace C3_5_C = . if (C3_5_C == 9)
replace C3_6_C = . if (C3_6_C == 9)
replace CATAGE = . if (CATAGE == 9)
replace CATAGE1C = . if (CATAGE1C == 9)
replace CIGFLAG = . if (CIGFLAG == 9)
replace CIGMON = . if (CIGMON == 9)
replace CIGYR = . if (CIGYR == 9)
replace CJDFLAG = . if (CJDFLAG == 9)
replace CJDYR = . if (CJDYR == 9)
replace CLEANWYR = . if (CLEANWYR == 9)
replace COCFLAG = . if (COCFLAG == 9)
replace COCMON = . if (COCMON == 9)
replace COCYR = . if (COCYR == 9)
replace COMFLAG = . if (COMFLAG == 9)
replace COOFLAG = . if (COOFLAG == 9)
replace COOMON = . if (COOMON == 9)
replace COOUIS = . if (COOUIS <= -1.00 )
replace COOYR = . if (COOYR == 9)
replace COUNSANY = . if (COUNSANY == 9)
replace COUNSMON = . if (COUNSMON == 9)
replace COUNSYR = . if (COUNSYR == 9)
replace CRIFLAG = . if (CRIFLAG == 9)
replace CRKFLAG = . if (CRKFLAG == 9)
replace CRKMON = . if (CRKMON == 9)
replace CRKUIS = . if (CRKUIS <= -1.00 )
replace CRKYR = . if (CRKYR == 9)
replace D1F_C = . if (D1F_C == 9)
replace D1_C = . if (D1_C == 9)
replace DAYSTAT = . if (DAYSTAT <= -1 )
replace DPRSUM = . if (DPRSUM == 9)
replace DPRSUM_C = . if (DPRSUM_C == 9)
replace DRUGFRST = . if (DRUGFRST == 9)
replace EDUCAT1C = . if (EDUCAT1C == 9)
replace EDUCCAT = . if (EDUCCAT == 9)
replace ELSEANY = . if (ELSEANY == 9)
replace ELSEGRP = . if (ELSEGRP == 9)
replace EMPL_MON = . if (EMPL_MON == 9)
replace EMPSTAT = . if (EMPSTAT == 9)
replace EMPYRF = . if (EMPYRF == 9)
replace EXPALL = . if (EXPALL <= -1 )
replace EXPILL = . if (EXPILL <= -1 )
replace EXPLEG = . if (EXPLEG <= -1 )
replace F7A_MON = . if (F7A_MON == 9)
replace F7A_YR = . if (F7A_YR == 9)
replace F8B_C = . if (F8B_C == 9)
replace F8_MON = . if (F8_MON == 9)
replace F8_YR = . if (F8_YR == 9)
replace GNDLOTHR = . if (GNDLOTHR == 9)
replace GRQFLAG = . if (GRQFLAG == 9)
replace GRQYR = . if (GRQYR == 9)
replace H1C_C = . if (H1C_C == 9)
replace H1N_C = . if (H1N_C == 9)
replace H2_C = . if (H2_C == 9)
replace HALFLAG = . if (HALFLAG == 9)
replace HALMON = . if (HALMON == 9)
replace HALUIS = . if (HALUIS <= -1.00 )
replace HALYR = . if (HALYR == 9)
replace HERFLAG = . if (HERFLAG == 9)
replace HERMON = . if (HERMON == 9)
replace HERUIS = . if (HERUIS <= -1.00 )
replace HERYR = . if (HERYR == 9)
replace HMLFLAG = . if (HMLFLAG == 9)
replace HMLYR = . if (HMLYR == 9)
replace HOMAGE = . if (HOMAGE == 9)
replace HOMDAYS = . if (HOMDAYS <= -1 )
replace HOMFLAG = . if (HOMFLAG == 9)
replace HOMLAST = . if (HOMLAST <= -1 )
replace HOMLGTH = . if (HOMLGTH == 9)
replace HOMTMS = . if (HOMTMS == 9)
replace HOUFLAG = . if (HOUFLAG == 9)
replace HOUYR = . if (HOUYR == 9)
replace HRS_MON = . if (HRS_MON == 9)
replace HVYDRK = . if (HVYDRK == 9)
replace HVYMON = . if (HVYMON == 9)
replace HVYUIS = . if (HVYUIS <= -1.00 )
replace IEMCRKYR = . if (IEMCRKYR == 9)
replace IEMFLAG = . if (IEMFLAG == 9)
replace IEMMON = . if (IEMMON == 9)
replace IEMYR = . if (IEMYR == 9)
replace INCALL = . if (INCALL <= -1 )
replace INCEB = . if (INCEB <= -1 )
replace INCERN = . if (INCERN <= -1 )
replace INCFLAG = . if (INCFLAG == 9)
replace INCILL = . if (INCILL <= -1 )
replace INCLEG = . if (INCLEG <= -1 )
replace INCOEN = . if (INCOEN <= -1 )
replace INCOTH = . if (INCOTH <= -1 )
replace INCYR = . if (INCYR == 9)
replace INHFLAG = . if (INHFLAG == 9)
replace INHMON = . if (INHMON == 9)
replace INHUIS = . if (INHUIS <= -1.00 )
replace INHYR = . if (INHYR == 9)
replace INJCOC = . if (INJCOC == 9)
replace INJHER = . if (INJHER == 9)
replace INJPSY = . if (INJPSY == 9)
replace INSANY = . if (INSANY == 9)
replace INSFLAG = . if (INSFLAG == 9)
replace INSPRI = . if (INSPRI == 9)
replace INSPRTX = . if (INSPRTX == 9)
replace INSPUB = . if (INSPUB == 9)
replace INSPUTX = . if (INSPUTX == 9)
replace INSYR = . if (INSYR == 9)
replace LOCATION = . if (LOCATION == 9)
replace LOCLTS1 = . if (LOCLTS1 == 9)
replace LOCPCE1 = . if (LOCPCE1 == 9)
replace LOCPN1 = . if (LOCPN1 == 9)
replace MARSTAT = . if (MARSTAT == 9)
replace MCKANY = . if (MCKANY == 9)
replace MCKFAM = . if (MCKFAM == 9)
replace MCKILL = . if (MCKILL == 9)
replace MCKUN = . if (MCKUN <= -1 )
replace MCKVET = . if (MCKVET == 9)
replace MCKYOU = . if (MCKYOU == 9)
replace METFLAG = . if (METFLAG == 9)
replace METMON = . if (METMON == 9)
replace METUIS = . if (METUIS <= -1.00 )
replace METYR = . if (METYR == 9)
replace MHSM30_C = . if (MHSM30_C == 9)
replace MHSUM = . if (MHSUM == -8)
replace MHSUM30 = . if (MHSUM30 == -8)
replace MHSUM_C = . if (MHSUM_C == 9)
replace MHTX30 = . if (MHTX30 == 9)
replace MHTXFL = . if (MHTXFL == 9)
replace MRJFLAG = . if (MRJFLAG == 9)
replace MRJMON = . if (MRJMON == 9)
replace MRJUIS = . if (MRJUIS <= -1.00 )
replace MRJYR = . if (MRJYR == 9)
replace NDLFLAG = . if (NDLFLAG == 9)
replace NDLMON = . if (NDLMON == 9)
replace NDLYR = . if (NDLYR == 9)
replace NETALL = . if (NETALL == -8888)
replace NETERN = . if (NETERN == -8888)
replace NETILL = . if (NETILL == -8888)
replace NETLEG = . if (NETLEG == -8888)
replace NPSNDLYR = . if (NPSNDLYR == 9)
replace OINYR = . if (OINYR == 9)
replace OTHRLA = . if (OTHRLA == 9)
replace OTHRTCD = . if (OTHRTCD == 9)
replace OTHRUWA = . if (OTHRUWA == 9)
replace OTHRWS = . if (OTHRWS == 9)
replace OWNANY = . if (OWNANY == 9)
replace OWNGRP = . if (OWNGRP == 9)
replace PATFLAG = . if (PATFLAG <= -1 )
replace PATFLAG3 = . if (PATFLAG3 == 9)
replace PATMON = . if (PATMON <= -1 )
replace PATMON3 = . if (PATMON3 == 9)
replace PATYR = . if (PATYR <= -1 )
replace PATYR3 = . if (PATYR3 == 9)
replace PCPDRG = . if (PCPDRG == 9)
replace PCPILL = . if (PCPILL == 9)
replace PCPSUM = . if (PCPSUM == -8)
replace PCPSUM_C = . if (PCPSUM_C == 9)
replace POVIG = . if (POVIG <= -1 )
replace POVIND_C = . if (POVIND_C == 9)
replace POVNP = . if (POVNP == -8)
replace PRGFLAG = . if (PRGFLAG <= -1 )
replace PRGYR = . if (PRGYR <= -1 )
replace PSYFLAG = . if (PSYFLAG == 9)
replace PSYMON = . if (PSYMON == 9)
replace PSYYR = . if (PSYYR == 9)
replace RACE = . if (RACE == 9)
replace SDFLAG = . if (SDFLAG <= -1 )
replace SERDAY = . if (SERDAY == 9)
replace SERFLAG = . if (SERFLAG == 9)
replace SERMON = . if (SERMON == 9)
replace SHOOTGYR = . if (SHOOTGYR == 9)
replace SKMEAL = . if (SKMEAL == 9)
replace SKSIT = . if (SKSIT == 9)
replace STAFLAG = . if (STAFLAG == 9)
replace STAMON = . if (STAMON == 9)
replace STAUIS = . if (STAUIS <= -1.00 )
replace STAYR = . if (STAYR == 9)
replace STMFLAG = . if (STMFLAG == 9)
replace STMMON = . if (STMMON == 9)
replace STMUIS = . if (STMUIS <= -1.00 )
replace STMYR = . if (STMYR == 9)
replace TXFLAG = . if (TXFLAG == 9)
replace TXYR = . if (TXYR == 9)
replace UOLDNDL = . if (UOLDNDL == 9)
replace WKCOR = . if (WKCOR <= -1 )
replace WKELSE = . if (WKELSE <= -1 )
replace WKGQ = . if (WKGQ <= -1 )
replace WKHOU = . if (WKHOU <= -1 )
replace WKNUR = . if (WKNUR <= -1 )
replace WKOS = . if (WKOS <= -1 )
replace WKSH = . if (WKSH <= -1 )
replace WKST = . if (WKST <= -1 )
replace WKSUM = . if (WKSUM <= -1 )
replace WKTXF = . if (WKTXF <= -1 )
replace ZDURAT = . if (ZDURAT <= -1 )
replace H1A_C = . if (H1A_C <= -1 )
replace POVIND = . if (POVIND <= -1.0000 )


*/
/********************************************************************

 Section 5: Save Outfile

  This section saves out a Stata system format file.  There is no reason to
  modify it if the macros in Section 1 were specified correctly.

*********************************************************************/

save `outfile', replace

